// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_ALL_LOW_RD_IS_RN_IN_IT_BLOCK_ADC_T32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_ALL_LOW_RD_IS_RN_IN_IT_BLOCK_ADC_T32_H_

const byte kInstruction_adc_gt_r3_r3_r0[] = {
  0xc8, 0xbf, 0x43, 0x41 // It gt; adc gt r3 r3 r0
};
const byte kInstruction_adc_ge_r6_r6_r1[] = {
  0xa8, 0xbf, 0x4e, 0x41 // It ge; adc ge r6 r6 r1
};
const byte kInstruction_adc_gt_r7_r7_r1[] = {
  0xc8, 0xbf, 0x4f, 0x41 // It gt; adc gt r7 r7 r1
};
const byte kInstruction_adc_gt_r2_r2_r0[] = {
  0xc8, 0xbf, 0x42, 0x41 // It gt; adc gt r2 r2 r0
};
const byte kInstruction_adc_eq_r5_r5_r2[] = {
  0x08, 0xbf, 0x55, 0x41 // It eq; adc eq r5 r5 r2
};
const byte kInstruction_adc_gt_r0_r0_r0[] = {
  0xc8, 0xbf, 0x40, 0x41 // It gt; adc gt r0 r0 r0
};
const byte kInstruction_adc_lt_r0_r0_r4[] = {
  0xb8, 0xbf, 0x60, 0x41 // It lt; adc lt r0 r0 r4
};
const byte kInstruction_adc_hi_r6_r6_r3[] = {
  0x88, 0xbf, 0x5e, 0x41 // It hi; adc hi r6 r6 r3
};
const byte kInstruction_adc_ge_r7_r7_r6[] = {
  0xa8, 0xbf, 0x77, 0x41 // It ge; adc ge r7 r7 r6
};
const byte kInstruction_adc_eq_r5_r5_r5[] = {
  0x08, 0xbf, 0x6d, 0x41 // It eq; adc eq r5 r5 r5
};
const byte kInstruction_adc_cc_r1_r1_r0[] = {
  0x38, 0xbf, 0x41, 0x41 // It cc; adc cc r1 r1 r0
};
const byte kInstruction_adc_cc_r1_r1_r1[] = {
  0x38, 0xbf, 0x49, 0x41 // It cc; adc cc r1 r1 r1
};
const byte kInstruction_adc_cc_r4_r4_r3[] = {
  0x38, 0xbf, 0x5c, 0x41 // It cc; adc cc r4 r4 r3
};
const byte kInstruction_adc_mi_r5_r5_r3[] = {
  0x48, 0xbf, 0x5d, 0x41 // It mi; adc mi r5 r5 r3
};
const byte kInstruction_adc_cs_r3_r3_r0[] = {
  0x28, 0xbf, 0x43, 0x41 // It cs; adc cs r3 r3 r0
};
const byte kInstruction_adc_pl_r0_r0_r6[] = {
  0x58, 0xbf, 0x70, 0x41 // It pl; adc pl r0 r0 r6
};
const byte kInstruction_adc_cc_r4_r4_r4[] = {
  0x38, 0xbf, 0x64, 0x41 // It cc; adc cc r4 r4 r4
};
const byte kInstruction_adc_cc_r3_r3_r6[] = {
  0x38, 0xbf, 0x73, 0x41 // It cc; adc cc r3 r3 r6
};
const byte kInstruction_adc_hi_r7_r7_r3[] = {
  0x88, 0xbf, 0x5f, 0x41 // It hi; adc hi r7 r7 r3
};
const byte kInstruction_adc_vs_r7_r7_r5[] = {
  0x68, 0xbf, 0x6f, 0x41 // It vs; adc vs r7 r7 r5
};
const byte kInstruction_adc_le_r2_r2_r7[] = {
  0xd8, 0xbf, 0x7a, 0x41 // It le; adc le r2 r2 r7
};
const byte kInstruction_adc_le_r5_r5_r3[] = {
  0xd8, 0xbf, 0x5d, 0x41 // It le; adc le r5 r5 r3
};
const byte kInstruction_adc_vs_r1_r1_r5[] = {
  0x68, 0xbf, 0x69, 0x41 // It vs; adc vs r1 r1 r5
};
const byte kInstruction_adc_vs_r7_r7_r3[] = {
  0x68, 0xbf, 0x5f, 0x41 // It vs; adc vs r7 r7 r3
};
const byte kInstruction_adc_cc_r0_r0_r3[] = {
  0x38, 0xbf, 0x58, 0x41 // It cc; adc cc r0 r0 r3
};
const byte kInstruction_adc_cc_r2_r2_r5[] = {
  0x38, 0xbf, 0x6a, 0x41 // It cc; adc cc r2 r2 r5
};
const byte kInstruction_adc_gt_r7_r7_r7[] = {
  0xc8, 0xbf, 0x7f, 0x41 // It gt; adc gt r7 r7 r7
};
const byte kInstruction_adc_ls_r7_r7_r2[] = {
  0x98, 0xbf, 0x57, 0x41 // It ls; adc ls r7 r7 r2
};
const byte kInstruction_adc_lt_r0_r0_r2[] = {
  0xb8, 0xbf, 0x50, 0x41 // It lt; adc lt r0 r0 r2
};
const byte kInstruction_adc_ne_r3_r3_r4[] = {
  0x18, 0xbf, 0x63, 0x41 // It ne; adc ne r3 r3 r4
};
const byte kInstruction_adc_ge_r3_r3_r7[] = {
  0xa8, 0xbf, 0x7b, 0x41 // It ge; adc ge r3 r3 r7
};
const byte kInstruction_adc_hi_r5_r5_r7[] = {
  0x88, 0xbf, 0x7d, 0x41 // It hi; adc hi r5 r5 r7
};
const byte kInstruction_adc_vc_r0_r0_r3[] = {
  0x78, 0xbf, 0x58, 0x41 // It vc; adc vc r0 r0 r3
};
const byte kInstruction_adc_cc_r7_r7_r3[] = {
  0x38, 0xbf, 0x5f, 0x41 // It cc; adc cc r7 r7 r3
};
const byte kInstruction_adc_ls_r5_r5_r4[] = {
  0x98, 0xbf, 0x65, 0x41 // It ls; adc ls r5 r5 r4
};
const byte kInstruction_adc_vc_r0_r0_r1[] = {
  0x78, 0xbf, 0x48, 0x41 // It vc; adc vc r0 r0 r1
};
const byte kInstruction_adc_hi_r0_r0_r6[] = {
  0x88, 0xbf, 0x70, 0x41 // It hi; adc hi r0 r0 r6
};
const byte kInstruction_adc_mi_r7_r7_r3[] = {
  0x48, 0xbf, 0x5f, 0x41 // It mi; adc mi r7 r7 r3
};
const byte kInstruction_adc_cc_r7_r7_r4[] = {
  0x38, 0xbf, 0x67, 0x41 // It cc; adc cc r7 r7 r4
};
const byte kInstruction_adc_pl_r0_r0_r3[] = {
  0x58, 0xbf, 0x58, 0x41 // It pl; adc pl r0 r0 r3
};
const byte kInstruction_adc_ls_r5_r5_r0[] = {
  0x98, 0xbf, 0x45, 0x41 // It ls; adc ls r5 r5 r0
};
const byte kInstruction_adc_ls_r2_r2_r5[] = {
  0x98, 0xbf, 0x6a, 0x41 // It ls; adc ls r2 r2 r5
};
const byte kInstruction_adc_ls_r0_r0_r3[] = {
  0x98, 0xbf, 0x58, 0x41 // It ls; adc ls r0 r0 r3
};
const byte kInstruction_adc_pl_r5_r5_r1[] = {
  0x58, 0xbf, 0x4d, 0x41 // It pl; adc pl r5 r5 r1
};
const byte kInstruction_adc_mi_r1_r1_r1[] = {
  0x48, 0xbf, 0x49, 0x41 // It mi; adc mi r1 r1 r1
};
const byte kInstruction_adc_ls_r5_r5_r3[] = {
  0x98, 0xbf, 0x5d, 0x41 // It ls; adc ls r5 r5 r3
};
const byte kInstruction_adc_gt_r2_r2_r7[] = {
  0xc8, 0xbf, 0x7a, 0x41 // It gt; adc gt r2 r2 r7
};
const byte kInstruction_adc_ge_r2_r2_r5[] = {
  0xa8, 0xbf, 0x6a, 0x41 // It ge; adc ge r2 r2 r5
};
const byte kInstruction_adc_gt_r7_r7_r3[] = {
  0xc8, 0xbf, 0x5f, 0x41 // It gt; adc gt r7 r7 r3
};
const byte kInstruction_adc_vs_r6_r6_r3[] = {
  0x68, 0xbf, 0x5e, 0x41 // It vs; adc vs r6 r6 r3
};
const byte kInstruction_adc_cc_r1_r1_r7[] = {
  0x38, 0xbf, 0x79, 0x41 // It cc; adc cc r1 r1 r7
};
const byte kInstruction_adc_ls_r0_r0_r1[] = {
  0x98, 0xbf, 0x48, 0x41 // It ls; adc ls r0 r0 r1
};
const byte kInstruction_adc_gt_r3_r3_r1[] = {
  0xc8, 0xbf, 0x4b, 0x41 // It gt; adc gt r3 r3 r1
};
const byte kInstruction_adc_cs_r7_r7_r3[] = {
  0x28, 0xbf, 0x5f, 0x41 // It cs; adc cs r7 r7 r3
};
const byte kInstruction_adc_gt_r5_r5_r3[] = {
  0xc8, 0xbf, 0x5d, 0x41 // It gt; adc gt r5 r5 r3
};
const byte kInstruction_adc_le_r2_r2_r5[] = {
  0xd8, 0xbf, 0x6a, 0x41 // It le; adc le r2 r2 r5
};
const byte kInstruction_adc_ne_r1_r1_r0[] = {
  0x18, 0xbf, 0x41, 0x41 // It ne; adc ne r1 r1 r0
};
const byte kInstruction_adc_ne_r7_r7_r7[] = {
  0x18, 0xbf, 0x7f, 0x41 // It ne; adc ne r7 r7 r7
};
const byte kInstruction_adc_lt_r2_r2_r1[] = {
  0xb8, 0xbf, 0x4a, 0x41 // It lt; adc lt r2 r2 r1
};
const byte kInstruction_adc_vs_r3_r3_r1[] = {
  0x68, 0xbf, 0x4b, 0x41 // It vs; adc vs r3 r3 r1
};
const byte kInstruction_adc_gt_r7_r7_r5[] = {
  0xc8, 0xbf, 0x6f, 0x41 // It gt; adc gt r7 r7 r5
};
const byte kInstruction_adc_ls_r6_r6_r1[] = {
  0x98, 0xbf, 0x4e, 0x41 // It ls; adc ls r6 r6 r1
};
const byte kInstruction_adc_pl_r7_r7_r4[] = {
  0x58, 0xbf, 0x67, 0x41 // It pl; adc pl r7 r7 r4
};
const byte kInstruction_adc_ls_r6_r6_r7[] = {
  0x98, 0xbf, 0x7e, 0x41 // It ls; adc ls r6 r6 r7
};
const byte kInstruction_adc_eq_r5_r5_r3[] = {
  0x08, 0xbf, 0x5d, 0x41 // It eq; adc eq r5 r5 r3
};
const byte kInstruction_adc_lt_r2_r2_r7[] = {
  0xb8, 0xbf, 0x7a, 0x41 // It lt; adc lt r2 r2 r7
};
const byte kInstruction_adc_pl_r7_r7_r6[] = {
  0x58, 0xbf, 0x77, 0x41 // It pl; adc pl r7 r7 r6
};
const byte kInstruction_adc_cs_r1_r1_r6[] = {
  0x28, 0xbf, 0x71, 0x41 // It cs; adc cs r1 r1 r6
};
const byte kInstruction_adc_cs_r0_r0_r3[] = {
  0x28, 0xbf, 0x58, 0x41 // It cs; adc cs r0 r0 r3
};
const byte kInstruction_adc_mi_r3_r3_r2[] = {
  0x48, 0xbf, 0x53, 0x41 // It mi; adc mi r3 r3 r2
};
const byte kInstruction_adc_eq_r4_r4_r5[] = {
  0x08, 0xbf, 0x6c, 0x41 // It eq; adc eq r4 r4 r5
};
const byte kInstruction_adc_cs_r3_r3_r4[] = {
  0x28, 0xbf, 0x63, 0x41 // It cs; adc cs r3 r3 r4
};
const byte kInstruction_adc_ls_r7_r7_r6[] = {
  0x98, 0xbf, 0x77, 0x41 // It ls; adc ls r7 r7 r6
};
const byte kInstruction_adc_vs_r0_r0_r7[] = {
  0x68, 0xbf, 0x78, 0x41 // It vs; adc vs r0 r0 r7
};
const byte kInstruction_adc_pl_r2_r2_r1[] = {
  0x58, 0xbf, 0x4a, 0x41 // It pl; adc pl r2 r2 r1
};
const byte kInstruction_adc_vs_r0_r0_r5[] = {
  0x68, 0xbf, 0x68, 0x41 // It vs; adc vs r0 r0 r5
};
const byte kInstruction_adc_vc_r4_r4_r2[] = {
  0x78, 0xbf, 0x54, 0x41 // It vc; adc vc r4 r4 r2
};
const byte kInstruction_adc_vc_r4_r4_r7[] = {
  0x78, 0xbf, 0x7c, 0x41 // It vc; adc vc r4 r4 r7
};
const byte kInstruction_adc_cs_r4_r4_r7[] = {
  0x28, 0xbf, 0x7c, 0x41 // It cs; adc cs r4 r4 r7
};
const byte kInstruction_adc_ne_r5_r5_r2[] = {
  0x18, 0xbf, 0x55, 0x41 // It ne; adc ne r5 r5 r2
};
const byte kInstruction_adc_eq_r1_r1_r5[] = {
  0x08, 0xbf, 0x69, 0x41 // It eq; adc eq r1 r1 r5
};
const byte kInstruction_adc_cc_r0_r0_r7[] = {
  0x38, 0xbf, 0x78, 0x41 // It cc; adc cc r0 r0 r7
};
const byte kInstruction_adc_lt_r4_r4_r0[] = {
  0xb8, 0xbf, 0x44, 0x41 // It lt; adc lt r4 r4 r0
};
const byte kInstruction_adc_eq_r2_r2_r6[] = {
  0x08, 0xbf, 0x72, 0x41 // It eq; adc eq r2 r2 r6
};
const byte kInstruction_adc_le_r2_r2_r1[] = {
  0xd8, 0xbf, 0x4a, 0x41 // It le; adc le r2 r2 r1
};
const byte kInstruction_adc_mi_r4_r4_r4[] = {
  0x48, 0xbf, 0x64, 0x41 // It mi; adc mi r4 r4 r4
};
const byte kInstruction_adc_ne_r5_r5_r6[] = {
  0x18, 0xbf, 0x75, 0x41 // It ne; adc ne r5 r5 r6
};
const byte kInstruction_adc_gt_r0_r0_r7[] = {
  0xc8, 0xbf, 0x78, 0x41 // It gt; adc gt r0 r0 r7
};
const byte kInstruction_adc_hi_r2_r2_r7[] = {
  0x88, 0xbf, 0x7a, 0x41 // It hi; adc hi r2 r2 r7
};
const byte kInstruction_adc_vs_r5_r5_r6[] = {
  0x68, 0xbf, 0x75, 0x41 // It vs; adc vs r5 r5 r6
};
const byte kInstruction_adc_eq_r4_r4_r1[] = {
  0x08, 0xbf, 0x4c, 0x41 // It eq; adc eq r4 r4 r1
};
const byte kInstruction_adc_eq_r7_r7_r0[] = {
  0x08, 0xbf, 0x47, 0x41 // It eq; adc eq r7 r7 r0
};
const byte kInstruction_adc_ne_r2_r2_r6[] = {
  0x18, 0xbf, 0x72, 0x41 // It ne; adc ne r2 r2 r6
};
const byte kInstruction_adc_vc_r4_r4_r1[] = {
  0x78, 0xbf, 0x4c, 0x41 // It vc; adc vc r4 r4 r1
};
const byte kInstruction_adc_le_r2_r2_r0[] = {
  0xd8, 0xbf, 0x42, 0x41 // It le; adc le r2 r2 r0
};
const byte kInstruction_adc_lt_r5_r5_r5[] = {
  0xb8, 0xbf, 0x6d, 0x41 // It lt; adc lt r5 r5 r5
};
const byte kInstruction_adc_pl_r3_r3_r7[] = {
  0x58, 0xbf, 0x7b, 0x41 // It pl; adc pl r3 r3 r7
};
const byte kInstruction_adc_pl_r1_r1_r5[] = {
  0x58, 0xbf, 0x69, 0x41 // It pl; adc pl r1 r1 r5
};
const byte kInstruction_adc_le_r3_r3_r1[] = {
  0xd8, 0xbf, 0x4b, 0x41 // It le; adc le r3 r3 r1
};
const byte kInstruction_adc_vs_r3_r3_r2[] = {
  0x68, 0xbf, 0x53, 0x41 // It vs; adc vs r3 r3 r2
};
const byte kInstruction_adc_pl_r1_r1_r3[] = {
  0x58, 0xbf, 0x59, 0x41 // It pl; adc pl r1 r1 r3
};
const byte kInstruction_adc_le_r4_r4_r3[] = {
  0xd8, 0xbf, 0x5c, 0x41 // It le; adc le r4 r4 r3
};
const byte kInstruction_adc_vs_r6_r6_r1[] = {
  0x68, 0xbf, 0x4e, 0x41 // It vs; adc vs r6 r6 r1
};
const byte kInstruction_adc_cs_r1_r1_r1[] = {
  0x28, 0xbf, 0x49, 0x41 // It cs; adc cs r1 r1 r1
};
const byte kInstruction_adc_ge_r2_r2_r6[] = {
  0xa8, 0xbf, 0x72, 0x41 // It ge; adc ge r2 r2 r6
};
const byte kInstruction_adc_ls_r0_r0_r0[] = {
  0x98, 0xbf, 0x40, 0x41 // It ls; adc ls r0 r0 r0
};
const byte kInstruction_adc_mi_r5_r5_r1[] = {
  0x48, 0xbf, 0x4d, 0x41 // It mi; adc mi r5 r5 r1
};
const byte kInstruction_adc_hi_r4_r4_r1[] = {
  0x88, 0xbf, 0x4c, 0x41 // It hi; adc hi r4 r4 r1
};
const byte kInstruction_adc_eq_r3_r3_r2[] = {
  0x08, 0xbf, 0x53, 0x41 // It eq; adc eq r3 r3 r2
};
const byte kInstruction_adc_cc_r5_r5_r1[] = {
  0x38, 0xbf, 0x4d, 0x41 // It cc; adc cc r5 r5 r1
};
const byte kInstruction_adc_eq_r6_r6_r2[] = {
  0x08, 0xbf, 0x56, 0x41 // It eq; adc eq r6 r6 r2
};
const byte kInstruction_adc_hi_r4_r4_r2[] = {
  0x88, 0xbf, 0x54, 0x41 // It hi; adc hi r4 r4 r2
};
const byte kInstruction_adc_gt_r5_r5_r0[] = {
  0xc8, 0xbf, 0x45, 0x41 // It gt; adc gt r5 r5 r0
};
const byte kInstruction_adc_hi_r3_r3_r2[] = {
  0x88, 0xbf, 0x53, 0x41 // It hi; adc hi r3 r3 r2
};
const byte kInstruction_adc_pl_r0_r0_r0[] = {
  0x58, 0xbf, 0x40, 0x41 // It pl; adc pl r0 r0 r0
};
const byte kInstruction_adc_lt_r3_r3_r7[] = {
  0xb8, 0xbf, 0x7b, 0x41 // It lt; adc lt r3 r3 r7
};
const byte kInstruction_adc_ls_r7_r7_r1[] = {
  0x98, 0xbf, 0x4f, 0x41 // It ls; adc ls r7 r7 r1
};
const byte kInstruction_adc_gt_r3_r3_r3[] = {
  0xc8, 0xbf, 0x5b, 0x41 // It gt; adc gt r3 r3 r3
};
const byte kInstruction_adc_cs_r6_r6_r6[] = {
  0x28, 0xbf, 0x76, 0x41 // It cs; adc cs r6 r6 r6
};
const byte kInstruction_adc_cc_r3_r3_r2[] = {
  0x38, 0xbf, 0x53, 0x41 // It cc; adc cc r3 r3 r2
};
const byte kInstruction_adc_ne_r4_r4_r0[] = {
  0x18, 0xbf, 0x44, 0x41 // It ne; adc ne r4 r4 r0
};
const byte kInstruction_adc_vs_r4_r4_r5[] = {
  0x68, 0xbf, 0x6c, 0x41 // It vs; adc vs r4 r4 r5
};
const byte kInstruction_adc_ge_r6_r6_r4[] = {
  0xa8, 0xbf, 0x66, 0x41 // It ge; adc ge r6 r6 r4
};
const byte kInstruction_adc_ne_r5_r5_r3[] = {
  0x18, 0xbf, 0x5d, 0x41 // It ne; adc ne r5 r5 r3
};
const byte kInstruction_adc_vs_r3_r3_r0[] = {
  0x68, 0xbf, 0x43, 0x41 // It vs; adc vs r3 r3 r0
};
const byte kInstruction_adc_lt_r5_r5_r2[] = {
  0xb8, 0xbf, 0x55, 0x41 // It lt; adc lt r5 r5 r2
};
const byte kInstruction_adc_lt_r6_r6_r4[] = {
  0xb8, 0xbf, 0x66, 0x41 // It lt; adc lt r6 r6 r4
};
const byte kInstruction_adc_hi_r2_r2_r5[] = {
  0x88, 0xbf, 0x6a, 0x41 // It hi; adc hi r2 r2 r5
};
const byte kInstruction_adc_eq_r7_r7_r5[] = {
  0x08, 0xbf, 0x6f, 0x41 // It eq; adc eq r7 r7 r5
};
const byte kInstruction_adc_lt_r4_r4_r5[] = {
  0xb8, 0xbf, 0x6c, 0x41 // It lt; adc lt r4 r4 r5
};
const byte kInstruction_adc_ls_r7_r7_r3[] = {
  0x98, 0xbf, 0x5f, 0x41 // It ls; adc ls r7 r7 r3
};
const byte kInstruction_adc_lt_r3_r3_r5[] = {
  0xb8, 0xbf, 0x6b, 0x41 // It lt; adc lt r3 r3 r5
};
const byte kInstruction_adc_cs_r5_r5_r0[] = {
  0x28, 0xbf, 0x45, 0x41 // It cs; adc cs r5 r5 r0
};
const byte kInstruction_adc_vc_r2_r2_r3[] = {
  0x78, 0xbf, 0x5a, 0x41 // It vc; adc vc r2 r2 r3
};
const byte kInstruction_adc_cs_r1_r1_r4[] = {
  0x28, 0xbf, 0x61, 0x41 // It cs; adc cs r1 r1 r4
};
const byte kInstruction_adc_pl_r5_r5_r4[] = {
  0x58, 0xbf, 0x65, 0x41 // It pl; adc pl r5 r5 r4
};
const byte kInstruction_adc_hi_r7_r7_r4[] = {
  0x88, 0xbf, 0x67, 0x41 // It hi; adc hi r7 r7 r4
};
const byte kInstruction_adc_ge_r3_r3_r6[] = {
  0xa8, 0xbf, 0x73, 0x41 // It ge; adc ge r3 r3 r6
};
const byte kInstruction_adc_ls_r3_r3_r2[] = {
  0x98, 0xbf, 0x53, 0x41 // It ls; adc ls r3 r3 r2
};
const byte kInstruction_adc_mi_r3_r3_r3[] = {
  0x48, 0xbf, 0x5b, 0x41 // It mi; adc mi r3 r3 r3
};
const byte kInstruction_adc_le_r6_r6_r5[] = {
  0xd8, 0xbf, 0x6e, 0x41 // It le; adc le r6 r6 r5
};
const byte kInstruction_adc_pl_r5_r5_r7[] = {
  0x58, 0xbf, 0x7d, 0x41 // It pl; adc pl r5 r5 r7
};
const byte kInstruction_adc_ne_r2_r2_r3[] = {
  0x18, 0xbf, 0x5a, 0x41 // It ne; adc ne r2 r2 r3
};
const byte kInstruction_adc_ls_r2_r2_r6[] = {
  0x98, 0xbf, 0x72, 0x41 // It ls; adc ls r2 r2 r6
};
const byte kInstruction_adc_le_r1_r1_r6[] = {
  0xd8, 0xbf, 0x71, 0x41 // It le; adc le r1 r1 r6
};
const byte kInstruction_adc_cc_r6_r6_r7[] = {
  0x38, 0xbf, 0x7e, 0x41 // It cc; adc cc r6 r6 r7
};
const byte kInstruction_adc_pl_r4_r4_r3[] = {
  0x58, 0xbf, 0x5c, 0x41 // It pl; adc pl r4 r4 r3
};
const byte kInstruction_adc_ne_r0_r0_r3[] = {
  0x18, 0xbf, 0x58, 0x41 // It ne; adc ne r0 r0 r3
};
const byte kInstruction_adc_cc_r6_r6_r6[] = {
  0x38, 0xbf, 0x76, 0x41 // It cc; adc cc r6 r6 r6
};
const byte kInstruction_adc_ls_r7_r7_r5[] = {
  0x98, 0xbf, 0x6f, 0x41 // It ls; adc ls r7 r7 r5
};
const byte kInstruction_adc_ls_r1_r1_r5[] = {
  0x98, 0xbf, 0x69, 0x41 // It ls; adc ls r1 r1 r5
};
const byte kInstruction_adc_le_r0_r0_r0[] = {
  0xd8, 0xbf, 0x40, 0x41 // It le; adc le r0 r0 r0
};
const byte kInstruction_adc_ge_r4_r4_r6[] = {
  0xa8, 0xbf, 0x74, 0x41 // It ge; adc ge r4 r4 r6
};
const byte kInstruction_adc_cc_r1_r1_r6[] = {
  0x38, 0xbf, 0x71, 0x41 // It cc; adc cc r1 r1 r6
};
const byte kInstruction_adc_eq_r4_r4_r3[] = {
  0x08, 0xbf, 0x5c, 0x41 // It eq; adc eq r4 r4 r3
};
const byte kInstruction_adc_ls_r7_r7_r4[] = {
  0x98, 0xbf, 0x67, 0x41 // It ls; adc ls r7 r7 r4
};
const byte kInstruction_adc_eq_r3_r3_r0[] = {
  0x08, 0xbf, 0x43, 0x41 // It eq; adc eq r3 r3 r0
};
const byte kInstruction_adc_lt_r4_r4_r3[] = {
  0xb8, 0xbf, 0x5c, 0x41 // It lt; adc lt r4 r4 r3
};
const byte kInstruction_adc_le_r3_r3_r4[] = {
  0xd8, 0xbf, 0x63, 0x41 // It le; adc le r3 r3 r4
};
const byte kInstruction_adc_le_r4_r4_r4[] = {
  0xd8, 0xbf, 0x64, 0x41 // It le; adc le r4 r4 r4
};
const byte kInstruction_adc_ge_r0_r0_r6[] = {
  0xa8, 0xbf, 0x70, 0x41 // It ge; adc ge r0 r0 r6
};
const byte kInstruction_adc_hi_r7_r7_r2[] = {
  0x88, 0xbf, 0x57, 0x41 // It hi; adc hi r7 r7 r2
};
const byte kInstruction_adc_pl_r5_r5_r6[] = {
  0x58, 0xbf, 0x75, 0x41 // It pl; adc pl r5 r5 r6
};
const byte kInstruction_adc_pl_r4_r4_r7[] = {
  0x58, 0xbf, 0x7c, 0x41 // It pl; adc pl r4 r4 r7
};
const byte kInstruction_adc_gt_r3_r3_r6[] = {
  0xc8, 0xbf, 0x73, 0x41 // It gt; adc gt r3 r3 r6
};
const byte kInstruction_adc_eq_r6_r6_r6[] = {
  0x08, 0xbf, 0x76, 0x41 // It eq; adc eq r6 r6 r6
};
const byte kInstruction_adc_cc_r5_r5_r0[] = {
  0x38, 0xbf, 0x45, 0x41 // It cc; adc cc r5 r5 r0
};
const byte kInstruction_adc_hi_r5_r5_r0[] = {
  0x88, 0xbf, 0x45, 0x41 // It hi; adc hi r5 r5 r0
};
const byte kInstruction_adc_gt_r5_r5_r5[] = {
  0xc8, 0xbf, 0x6d, 0x41 // It gt; adc gt r5 r5 r5
};
const byte kInstruction_adc_vs_r2_r2_r4[] = {
  0x68, 0xbf, 0x62, 0x41 // It vs; adc vs r2 r2 r4
};
const byte kInstruction_adc_vs_r1_r1_r3[] = {
  0x68, 0xbf, 0x59, 0x41 // It vs; adc vs r1 r1 r3
};
const byte kInstruction_adc_lt_r7_r7_r6[] = {
  0xb8, 0xbf, 0x77, 0x41 // It lt; adc lt r7 r7 r6
};
const byte kInstruction_adc_ge_r2_r2_r2[] = {
  0xa8, 0xbf, 0x52, 0x41 // It ge; adc ge r2 r2 r2
};
const byte kInstruction_adc_mi_r1_r1_r5[] = {
  0x48, 0xbf, 0x69, 0x41 // It mi; adc mi r1 r1 r5
};
const byte kInstruction_adc_ge_r5_r5_r0[] = {
  0xa8, 0xbf, 0x45, 0x41 // It ge; adc ge r5 r5 r0
};
const byte kInstruction_adc_le_r6_r6_r3[] = {
  0xd8, 0xbf, 0x5e, 0x41 // It le; adc le r6 r6 r3
};
const byte kInstruction_adc_hi_r7_r7_r5[] = {
  0x88, 0xbf, 0x6f, 0x41 // It hi; adc hi r7 r7 r5
};
const byte kInstruction_adc_gt_r3_r3_r4[] = {
  0xc8, 0xbf, 0x63, 0x41 // It gt; adc gt r3 r3 r4
};
const byte kInstruction_adc_cc_r3_r3_r3[] = {
  0x38, 0xbf, 0x5b, 0x41 // It cc; adc cc r3 r3 r3
};
const byte kInstruction_adc_hi_r2_r2_r2[] = {
  0x88, 0xbf, 0x52, 0x41 // It hi; adc hi r2 r2 r2
};
const byte kInstruction_adc_lt_r7_r7_r3[] = {
  0xb8, 0xbf, 0x5f, 0x41 // It lt; adc lt r7 r7 r3
};
const byte kInstruction_adc_ls_r6_r6_r6[] = {
  0x98, 0xbf, 0x76, 0x41 // It ls; adc ls r6 r6 r6
};
const byte kInstruction_adc_le_r7_r7_r7[] = {
  0xd8, 0xbf, 0x7f, 0x41 // It le; adc le r7 r7 r7
};
const byte kInstruction_adc_cs_r4_r4_r6[] = {
  0x28, 0xbf, 0x74, 0x41 // It cs; adc cs r4 r4 r6
};
const byte kInstruction_adc_ge_r5_r5_r4[] = {
  0xa8, 0xbf, 0x65, 0x41 // It ge; adc ge r5 r5 r4
};
const byte kInstruction_adc_ge_r1_r1_r2[] = {
  0xa8, 0xbf, 0x51, 0x41 // It ge; adc ge r1 r1 r2
};
const byte kInstruction_adc_pl_r0_r0_r7[] = {
  0x58, 0xbf, 0x78, 0x41 // It pl; adc pl r0 r0 r7
};
const byte kInstruction_adc_vs_r1_r1_r2[] = {
  0x68, 0xbf, 0x51, 0x41 // It vs; adc vs r1 r1 r2
};
const byte kInstruction_adc_mi_r6_r6_r5[] = {
  0x48, 0xbf, 0x6e, 0x41 // It mi; adc mi r6 r6 r5
};
const byte kInstruction_adc_mi_r0_r0_r1[] = {
  0x48, 0xbf, 0x48, 0x41 // It mi; adc mi r0 r0 r1
};
const byte kInstruction_adc_vc_r0_r0_r5[] = {
  0x78, 0xbf, 0x68, 0x41 // It vc; adc vc r0 r0 r5
};
const byte kInstruction_adc_cc_r5_r5_r5[] = {
  0x38, 0xbf, 0x6d, 0x41 // It cc; adc cc r5 r5 r5
};
const byte kInstruction_adc_pl_r5_r5_r5[] = {
  0x58, 0xbf, 0x6d, 0x41 // It pl; adc pl r5 r5 r5
};
const byte kInstruction_adc_ne_r2_r2_r0[] = {
  0x18, 0xbf, 0x42, 0x41 // It ne; adc ne r2 r2 r0
};
const byte kInstruction_adc_cc_r3_r3_r4[] = {
  0x38, 0xbf, 0x63, 0x41 // It cc; adc cc r3 r3 r4
};
const byte kInstruction_adc_ls_r3_r3_r3[] = {
  0x98, 0xbf, 0x5b, 0x41 // It ls; adc ls r3 r3 r3
};
const byte kInstruction_adc_cc_r2_r2_r1[] = {
  0x38, 0xbf, 0x4a, 0x41 // It cc; adc cc r2 r2 r1
};
const byte kInstruction_adc_ge_r3_r3_r4[] = {
  0xa8, 0xbf, 0x63, 0x41 // It ge; adc ge r3 r3 r4
};
const byte kInstruction_adc_ne_r0_r0_r6[] = {
  0x18, 0xbf, 0x70, 0x41 // It ne; adc ne r0 r0 r6
};
const byte kInstruction_adc_vs_r2_r2_r0[] = {
  0x68, 0xbf, 0x42, 0x41 // It vs; adc vs r2 r2 r0
};
const byte kInstruction_adc_ne_r1_r1_r2[] = {
  0x18, 0xbf, 0x51, 0x41 // It ne; adc ne r1 r1 r2
};
const byte kInstruction_adc_ne_r6_r6_r5[] = {
  0x18, 0xbf, 0x6e, 0x41 // It ne; adc ne r6 r6 r5
};
const byte kInstruction_adc_pl_r7_r7_r0[] = {
  0x58, 0xbf, 0x47, 0x41 // It pl; adc pl r7 r7 r0
};
const byte kInstruction_adc_pl_r6_r6_r2[] = {
  0x58, 0xbf, 0x56, 0x41 // It pl; adc pl r6 r6 r2
};
const byte kInstruction_adc_pl_r1_r1_r2[] = {
  0x58, 0xbf, 0x51, 0x41 // It pl; adc pl r1 r1 r2
};
const byte kInstruction_adc_gt_r6_r6_r3[] = {
  0xc8, 0xbf, 0x5e, 0x41 // It gt; adc gt r6 r6 r3
};
const byte kInstruction_adc_vc_r0_r0_r4[] = {
  0x78, 0xbf, 0x60, 0x41 // It vc; adc vc r0 r0 r4
};
const byte kInstruction_adc_vc_r4_r4_r5[] = {
  0x78, 0xbf, 0x6c, 0x41 // It vc; adc vc r4 r4 r5
};
const byte kInstruction_adc_vs_r2_r2_r3[] = {
  0x68, 0xbf, 0x5a, 0x41 // It vs; adc vs r2 r2 r3
};
const byte kInstruction_adc_pl_r2_r2_r3[] = {
  0x58, 0xbf, 0x5a, 0x41 // It pl; adc pl r2 r2 r3
};
const byte kInstruction_adc_hi_r5_r5_r2[] = {
  0x88, 0xbf, 0x55, 0x41 // It hi; adc hi r5 r5 r2
};
const byte kInstruction_adc_le_r6_r6_r1[] = {
  0xd8, 0xbf, 0x4e, 0x41 // It le; adc le r6 r6 r1
};
const byte kInstruction_adc_ne_r3_r3_r0[] = {
  0x18, 0xbf, 0x43, 0x41 // It ne; adc ne r3 r3 r0
};
const byte kInstruction_adc_mi_r7_r7_r1[] = {
  0x48, 0xbf, 0x4f, 0x41 // It mi; adc mi r7 r7 r1
};
const byte kInstruction_adc_lt_r7_r7_r7[] = {
  0xb8, 0xbf, 0x7f, 0x41 // It lt; adc lt r7 r7 r7
};
const byte kInstruction_adc_gt_r5_r5_r7[] = {
  0xc8, 0xbf, 0x7d, 0x41 // It gt; adc gt r5 r5 r7
};
const byte kInstruction_adc_vc_r1_r1_r1[] = {
  0x78, 0xbf, 0x49, 0x41 // It vc; adc vc r1 r1 r1
};
const byte kInstruction_adc_lt_r1_r1_r2[] = {
  0xb8, 0xbf, 0x51, 0x41 // It lt; adc lt r1 r1 r2
};
const byte kInstruction_adc_vs_r6_r6_r6[] = {
  0x68, 0xbf, 0x76, 0x41 // It vs; adc vs r6 r6 r6
};
const byte kInstruction_adc_le_r5_r5_r5[] = {
  0xd8, 0xbf, 0x6d, 0x41 // It le; adc le r5 r5 r5
};
const byte kInstruction_adc_gt_r6_r6_r7[] = {
  0xc8, 0xbf, 0x7e, 0x41 // It gt; adc gt r6 r6 r7
};
const byte kInstruction_adc_cc_r3_r3_r1[] = {
  0x38, 0xbf, 0x4b, 0x41 // It cc; adc cc r3 r3 r1
};
const byte kInstruction_adc_ls_r1_r1_r0[] = {
  0x98, 0xbf, 0x41, 0x41 // It ls; adc ls r1 r1 r0
};
const byte kInstruction_adc_vs_r6_r6_r2[] = {
  0x68, 0xbf, 0x56, 0x41 // It vs; adc vs r6 r6 r2
};
const byte kInstruction_adc_mi_r7_r7_r0[] = {
  0x48, 0xbf, 0x47, 0x41 // It mi; adc mi r7 r7 r0
};
const byte kInstruction_adc_gt_r0_r0_r1[] = {
  0xc8, 0xbf, 0x48, 0x41 // It gt; adc gt r0 r0 r1
};
const byte kInstruction_adc_ne_r0_r0_r0[] = {
  0x18, 0xbf, 0x40, 0x41 // It ne; adc ne r0 r0 r0
};
const byte kInstruction_adc_lt_r6_r6_r1[] = {
  0xb8, 0xbf, 0x4e, 0x41 // It lt; adc lt r6 r6 r1
};
const byte kInstruction_adc_ge_r5_r5_r5[] = {
  0xa8, 0xbf, 0x6d, 0x41 // It ge; adc ge r5 r5 r5
};
const byte kInstruction_adc_lt_r2_r2_r4[] = {
  0xb8, 0xbf, 0x62, 0x41 // It lt; adc lt r2 r2 r4
};
const byte kInstruction_adc_vs_r4_r4_r3[] = {
  0x68, 0xbf, 0x5c, 0x41 // It vs; adc vs r4 r4 r3
};
const byte kInstruction_adc_cs_r5_r5_r2[] = {
  0x28, 0xbf, 0x55, 0x41 // It cs; adc cs r5 r5 r2
};
const byte kInstruction_adc_gt_r1_r1_r1[] = {
  0xc8, 0xbf, 0x49, 0x41 // It gt; adc gt r1 r1 r1
};
const byte kInstruction_adc_cs_r5_r5_r6[] = {
  0x28, 0xbf, 0x75, 0x41 // It cs; adc cs r5 r5 r6
};
const byte kInstruction_adc_gt_r6_r6_r2[] = {
  0xc8, 0xbf, 0x56, 0x41 // It gt; adc gt r6 r6 r2
};
const byte kInstruction_adc_cc_r2_r2_r0[] = {
  0x38, 0xbf, 0x42, 0x41 // It cc; adc cc r2 r2 r0
};
const byte kInstruction_adc_lt_r2_r2_r5[] = {
  0xb8, 0xbf, 0x6a, 0x41 // It lt; adc lt r2 r2 r5
};
const byte kInstruction_adc_mi_r1_r1_r6[] = {
  0x48, 0xbf, 0x71, 0x41 // It mi; adc mi r1 r1 r6
};
const byte kInstruction_adc_hi_r4_r4_r0[] = {
  0x88, 0xbf, 0x44, 0x41 // It hi; adc hi r4 r4 r0
};
const byte kInstruction_adc_le_r5_r5_r2[] = {
  0xd8, 0xbf, 0x55, 0x41 // It le; adc le r5 r5 r2
};
const byte kInstruction_adc_eq_r5_r5_r7[] = {
  0x08, 0xbf, 0x7d, 0x41 // It eq; adc eq r5 r5 r7
};
const byte kInstruction_adc_eq_r5_r5_r0[] = {
  0x08, 0xbf, 0x45, 0x41 // It eq; adc eq r5 r5 r0
};
const byte kInstruction_adc_le_r0_r0_r1[] = {
  0xd8, 0xbf, 0x48, 0x41 // It le; adc le r0 r0 r1
};
const byte kInstruction_adc_cs_r2_r2_r4[] = {
  0x28, 0xbf, 0x62, 0x41 // It cs; adc cs r2 r2 r4
};
const byte kInstruction_adc_cc_r5_r5_r4[] = {
  0x38, 0xbf, 0x65, 0x41 // It cc; adc cc r5 r5 r4
};
const byte kInstruction_adc_mi_r5_r5_r0[] = {
  0x48, 0xbf, 0x45, 0x41 // It mi; adc mi r5 r5 r0
};
const byte kInstruction_adc_le_r1_r1_r0[] = {
  0xd8, 0xbf, 0x41, 0x41 // It le; adc le r1 r1 r0
};
const byte kInstruction_adc_mi_r2_r2_r2[] = {
  0x48, 0xbf, 0x52, 0x41 // It mi; adc mi r2 r2 r2
};
const byte kInstruction_adc_ls_r4_r4_r2[] = {
  0x98, 0xbf, 0x54, 0x41 // It ls; adc ls r4 r4 r2
};
const byte kInstruction_adc_ne_r3_r3_r1[] = {
  0x18, 0xbf, 0x4b, 0x41 // It ne; adc ne r3 r3 r1
};
const byte kInstruction_adc_hi_r3_r3_r1[] = {
  0x88, 0xbf, 0x4b, 0x41 // It hi; adc hi r3 r3 r1
};
const byte kInstruction_adc_pl_r4_r4_r1[] = {
  0x58, 0xbf, 0x4c, 0x41 // It pl; adc pl r4 r4 r1
};
const byte kInstruction_adc_pl_r7_r7_r7[] = {
  0x58, 0xbf, 0x7f, 0x41 // It pl; adc pl r7 r7 r7
};
const byte kInstruction_adc_ge_r3_r3_r0[] = {
  0xa8, 0xbf, 0x43, 0x41 // It ge; adc ge r3 r3 r0
};
const byte kInstruction_adc_vs_r6_r6_r0[] = {
  0x68, 0xbf, 0x46, 0x41 // It vs; adc vs r6 r6 r0
};
const byte kInstruction_adc_gt_r1_r1_r5[] = {
  0xc8, 0xbf, 0x69, 0x41 // It gt; adc gt r1 r1 r5
};
const byte kInstruction_adc_ls_r1_r1_r7[] = {
  0x98, 0xbf, 0x79, 0x41 // It ls; adc ls r1 r1 r7
};
const byte kInstruction_adc_hi_r5_r5_r3[] = {
  0x88, 0xbf, 0x5d, 0x41 // It hi; adc hi r5 r5 r3
};
const byte kInstruction_adc_ls_r5_r5_r2[] = {
  0x98, 0xbf, 0x55, 0x41 // It ls; adc ls r5 r5 r2
};
const byte kInstruction_adc_ls_r6_r6_r2[] = {
  0x98, 0xbf, 0x56, 0x41 // It ls; adc ls r6 r6 r2
};
const byte kInstruction_adc_cs_r7_r7_r7[] = {
  0x28, 0xbf, 0x7f, 0x41 // It cs; adc cs r7 r7 r7
};
const byte kInstruction_adc_le_r3_r3_r2[] = {
  0xd8, 0xbf, 0x53, 0x41 // It le; adc le r3 r3 r2
};
const byte kInstruction_adc_le_r6_r6_r0[] = {
  0xd8, 0xbf, 0x46, 0x41 // It le; adc le r6 r6 r0
};
const byte kInstruction_adc_pl_r4_r4_r4[] = {
  0x58, 0xbf, 0x64, 0x41 // It pl; adc pl r4 r4 r4
};
const byte kInstruction_adc_ne_r1_r1_r3[] = {
  0x18, 0xbf, 0x59, 0x41 // It ne; adc ne r1 r1 r3
};
const byte kInstruction_adc_ge_r5_r5_r1[] = {
  0xa8, 0xbf, 0x4d, 0x41 // It ge; adc ge r5 r5 r1
};
const byte kInstruction_adc_eq_r4_r4_r7[] = {
  0x08, 0xbf, 0x7c, 0x41 // It eq; adc eq r4 r4 r7
};
const byte kInstruction_adc_pl_r7_r7_r1[] = {
  0x58, 0xbf, 0x4f, 0x41 // It pl; adc pl r7 r7 r1
};
const byte kInstruction_adc_vs_r6_r6_r7[] = {
  0x68, 0xbf, 0x7e, 0x41 // It vs; adc vs r6 r6 r7
};
const byte kInstruction_adc_vc_r2_r2_r6[] = {
  0x78, 0xbf, 0x72, 0x41 // It vc; adc vc r2 r2 r6
};
const byte kInstruction_adc_hi_r7_r7_r6[] = {
  0x88, 0xbf, 0x77, 0x41 // It hi; adc hi r7 r7 r6
};
const byte kInstruction_adc_le_r1_r1_r1[] = {
  0xd8, 0xbf, 0x49, 0x41 // It le; adc le r1 r1 r1
};
const byte kInstruction_adc_cs_r4_r4_r1[] = {
  0x28, 0xbf, 0x4c, 0x41 // It cs; adc cs r4 r4 r1
};
const byte kInstruction_adc_mi_r1_r1_r2[] = {
  0x48, 0xbf, 0x51, 0x41 // It mi; adc mi r1 r1 r2
};
const byte kInstruction_adc_pl_r3_r3_r5[] = {
  0x58, 0xbf, 0x6b, 0x41 // It pl; adc pl r3 r3 r5
};
const byte kInstruction_adc_eq_r7_r7_r1[] = {
  0x08, 0xbf, 0x4f, 0x41 // It eq; adc eq r7 r7 r1
};
const byte kInstruction_adc_cs_r0_r0_r5[] = {
  0x28, 0xbf, 0x68, 0x41 // It cs; adc cs r0 r0 r5
};
const byte kInstruction_adc_ge_r3_r3_r5[] = {
  0xa8, 0xbf, 0x6b, 0x41 // It ge; adc ge r3 r3 r5
};
const byte kInstruction_adc_pl_r6_r6_r3[] = {
  0x58, 0xbf, 0x5e, 0x41 // It pl; adc pl r6 r6 r3
};
const byte kInstruction_adc_cc_r7_r7_r5[] = {
  0x38, 0xbf, 0x6f, 0x41 // It cc; adc cc r7 r7 r5
};
const byte kInstruction_adc_lt_r4_r4_r6[] = {
  0xb8, 0xbf, 0x74, 0x41 // It lt; adc lt r4 r4 r6
};
const byte kInstruction_adc_ne_r7_r7_r2[] = {
  0x18, 0xbf, 0x57, 0x41 // It ne; adc ne r7 r7 r2
};
const byte kInstruction_adc_vc_r3_r3_r0[] = {
  0x78, 0xbf, 0x43, 0x41 // It vc; adc vc r3 r3 r0
};
const byte kInstruction_adc_cc_r7_r7_r6[] = {
  0x38, 0xbf, 0x77, 0x41 // It cc; adc cc r7 r7 r6
};
const byte kInstruction_adc_vc_r0_r0_r0[] = {
  0x78, 0xbf, 0x40, 0x41 // It vc; adc vc r0 r0 r0
};
const byte kInstruction_adc_vc_r7_r7_r3[] = {
  0x78, 0xbf, 0x5f, 0x41 // It vc; adc vc r7 r7 r3
};
const byte kInstruction_adc_vs_r7_r7_r0[] = {
  0x68, 0xbf, 0x47, 0x41 // It vs; adc vs r7 r7 r0
};
const byte kInstruction_adc_eq_r2_r2_r0[] = {
  0x08, 0xbf, 0x42, 0x41 // It eq; adc eq r2 r2 r0
};
const byte kInstruction_adc_ne_r2_r2_r1[] = {
  0x18, 0xbf, 0x4a, 0x41 // It ne; adc ne r2 r2 r1
};
const byte kInstruction_adc_pl_r7_r7_r2[] = {
  0x58, 0xbf, 0x57, 0x41 // It pl; adc pl r7 r7 r2
};
const byte kInstruction_adc_vc_r3_r3_r6[] = {
  0x78, 0xbf, 0x73, 0x41 // It vc; adc vc r3 r3 r6
};
const byte kInstruction_adc_vs_r5_r5_r1[] = {
  0x68, 0xbf, 0x4d, 0x41 // It vs; adc vs r5 r5 r1
};
const byte kInstruction_adc_vs_r2_r2_r2[] = {
  0x68, 0xbf, 0x52, 0x41 // It vs; adc vs r2 r2 r2
};
const byte kInstruction_adc_pl_r6_r6_r6[] = {
  0x58, 0xbf, 0x76, 0x41 // It pl; adc pl r6 r6 r6
};
const byte kInstruction_adc_ge_r6_r6_r3[] = {
  0xa8, 0xbf, 0x5e, 0x41 // It ge; adc ge r6 r6 r3
};
const byte kInstruction_adc_lt_r2_r2_r6[] = {
  0xb8, 0xbf, 0x72, 0x41 // It lt; adc lt r2 r2 r6
};
const byte kInstruction_adc_ls_r5_r5_r6[] = {
  0x98, 0xbf, 0x75, 0x41 // It ls; adc ls r5 r5 r6
};
const byte kInstruction_adc_le_r7_r7_r6[] = {
  0xd8, 0xbf, 0x77, 0x41 // It le; adc le r7 r7 r6
};
const byte kInstruction_adc_ge_r0_r0_r2[] = {
  0xa8, 0xbf, 0x50, 0x41 // It ge; adc ge r0 r0 r2
};
const byte kInstruction_adc_le_r0_r0_r4[] = {
  0xd8, 0xbf, 0x60, 0x41 // It le; adc le r0 r0 r4
};
const byte kInstruction_adc_ls_r6_r6_r3[] = {
  0x98, 0xbf, 0x5e, 0x41 // It ls; adc ls r6 r6 r3
};
const byte kInstruction_adc_ls_r6_r6_r0[] = {
  0x98, 0xbf, 0x46, 0x41 // It ls; adc ls r6 r6 r0
};
const byte kInstruction_adc_vs_r4_r4_r7[] = {
  0x68, 0xbf, 0x7c, 0x41 // It vs; adc vs r4 r4 r7
};
const byte kInstruction_adc_cs_r4_r4_r4[] = {
  0x28, 0xbf, 0x64, 0x41 // It cs; adc cs r4 r4 r4
};
const byte kInstruction_adc_cs_r7_r7_r5[] = {
  0x28, 0xbf, 0x6f, 0x41 // It cs; adc cs r7 r7 r5
};
const byte kInstruction_adc_cs_r6_r6_r3[] = {
  0x28, 0xbf, 0x5e, 0x41 // It cs; adc cs r6 r6 r3
};
const byte kInstruction_adc_eq_r7_r7_r4[] = {
  0x08, 0xbf, 0x67, 0x41 // It eq; adc eq r7 r7 r4
};
const byte kInstruction_adc_pl_r6_r6_r0[] = {
  0x58, 0xbf, 0x46, 0x41 // It pl; adc pl r6 r6 r0
};
const byte kInstruction_adc_hi_r5_r5_r4[] = {
  0x88, 0xbf, 0x65, 0x41 // It hi; adc hi r5 r5 r4
};
const byte kInstruction_adc_lt_r6_r6_r6[] = {
  0xb8, 0xbf, 0x76, 0x41 // It lt; adc lt r6 r6 r6
};
const byte kInstruction_adc_le_r7_r7_r2[] = {
  0xd8, 0xbf, 0x57, 0x41 // It le; adc le r7 r7 r2
};
const byte kInstruction_adc_le_r4_r4_r1[] = {
  0xd8, 0xbf, 0x4c, 0x41 // It le; adc le r4 r4 r1
};
const byte kInstruction_adc_ne_r4_r4_r6[] = {
  0x18, 0xbf, 0x74, 0x41 // It ne; adc ne r4 r4 r6
};
const byte kInstruction_adc_hi_r0_r0_r1[] = {
  0x88, 0xbf, 0x48, 0x41 // It hi; adc hi r0 r0 r1
};
const byte kInstruction_adc_gt_r6_r6_r5[] = {
  0xc8, 0xbf, 0x6e, 0x41 // It gt; adc gt r6 r6 r5
};
const byte kInstruction_adc_cc_r5_r5_r6[] = {
  0x38, 0xbf, 0x75, 0x41 // It cc; adc cc r5 r5 r6
};
const byte kInstruction_adc_ls_r3_r3_r4[] = {
  0x98, 0xbf, 0x63, 0x41 // It ls; adc ls r3 r3 r4
};
const byte kInstruction_adc_vc_r6_r6_r6[] = {
  0x78, 0xbf, 0x76, 0x41 // It vc; adc vc r6 r6 r6
};
const byte kInstruction_adc_pl_r4_r4_r2[] = {
  0x58, 0xbf, 0x54, 0x41 // It pl; adc pl r4 r4 r2
};
const byte kInstruction_adc_lt_r6_r6_r3[] = {
  0xb8, 0xbf, 0x5e, 0x41 // It lt; adc lt r6 r6 r3
};
const byte kInstruction_adc_mi_r1_r1_r0[] = {
  0x48, 0xbf, 0x41, 0x41 // It mi; adc mi r1 r1 r0
};
const byte kInstruction_adc_cc_r0_r0_r2[] = {
  0x38, 0xbf, 0x50, 0x41 // It cc; adc cc r0 r0 r2
};
const byte kInstruction_adc_ne_r5_r5_r5[] = {
  0x18, 0xbf, 0x6d, 0x41 // It ne; adc ne r5 r5 r5
};
const byte kInstruction_adc_cs_r7_r7_r4[] = {
  0x28, 0xbf, 0x67, 0x41 // It cs; adc cs r7 r7 r4
};
const byte kInstruction_adc_vc_r7_r7_r0[] = {
  0x78, 0xbf, 0x47, 0x41 // It vc; adc vc r7 r7 r0
};
const byte kInstruction_adc_cc_r2_r2_r2[] = {
  0x38, 0xbf, 0x52, 0x41 // It cc; adc cc r2 r2 r2
};
const byte kInstruction_adc_ge_r0_r0_r4[] = {
  0xa8, 0xbf, 0x60, 0x41 // It ge; adc ge r0 r0 r4
};
const byte kInstruction_adc_gt_r4_r4_r4[] = {
  0xc8, 0xbf, 0x64, 0x41 // It gt; adc gt r4 r4 r4
};
const byte kInstruction_adc_cs_r3_r3_r6[] = {
  0x28, 0xbf, 0x73, 0x41 // It cs; adc cs r3 r3 r6
};
const byte kInstruction_adc_cc_r4_r4_r2[] = {
  0x38, 0xbf, 0x54, 0x41 // It cc; adc cc r4 r4 r2
};
const byte kInstruction_adc_eq_r1_r1_r6[] = {
  0x08, 0xbf, 0x71, 0x41 // It eq; adc eq r1 r1 r6
};
const byte kInstruction_adc_mi_r4_r4_r6[] = {
  0x48, 0xbf, 0x74, 0x41 // It mi; adc mi r4 r4 r6
};
const byte kInstruction_adc_eq_r4_r4_r4[] = {
  0x08, 0xbf, 0x64, 0x41 // It eq; adc eq r4 r4 r4
};
const byte kInstruction_adc_gt_r2_r2_r6[] = {
  0xc8, 0xbf, 0x72, 0x41 // It gt; adc gt r2 r2 r6
};
const byte kInstruction_adc_lt_r5_r5_r7[] = {
  0xb8, 0xbf, 0x7d, 0x41 // It lt; adc lt r5 r5 r7
};
const byte kInstruction_adc_lt_r4_r4_r2[] = {
  0xb8, 0xbf, 0x54, 0x41 // It lt; adc lt r4 r4 r2
};
const byte kInstruction_adc_cs_r6_r6_r1[] = {
  0x28, 0xbf, 0x4e, 0x41 // It cs; adc cs r6 r6 r1
};
const byte kInstruction_adc_vs_r2_r2_r7[] = {
  0x68, 0xbf, 0x7a, 0x41 // It vs; adc vs r2 r2 r7
};
const byte kInstruction_adc_hi_r6_r6_r6[] = {
  0x88, 0xbf, 0x76, 0x41 // It hi; adc hi r6 r6 r6
};
const byte kInstruction_adc_vs_r0_r0_r3[] = {
  0x68, 0xbf, 0x58, 0x41 // It vs; adc vs r0 r0 r3
};
const byte kInstruction_adc_mi_r0_r0_r2[] = {
  0x48, 0xbf, 0x50, 0x41 // It mi; adc mi r0 r0 r2
};
const byte kInstruction_adc_cs_r7_r7_r1[] = {
  0x28, 0xbf, 0x4f, 0x41 // It cs; adc cs r7 r7 r1
};
const byte kInstruction_adc_gt_r1_r1_r6[] = {
  0xc8, 0xbf, 0x71, 0x41 // It gt; adc gt r1 r1 r6
};
const byte kInstruction_adc_vs_r3_r3_r7[] = {
  0x68, 0xbf, 0x7b, 0x41 // It vs; adc vs r3 r3 r7
};
const byte kInstruction_adc_hi_r1_r1_r5[] = {
  0x88, 0xbf, 0x69, 0x41 // It hi; adc hi r1 r1 r5
};
const byte kInstruction_adc_lt_r4_r4_r1[] = {
  0xb8, 0xbf, 0x4c, 0x41 // It lt; adc lt r4 r4 r1
};
const byte kInstruction_adc_le_r6_r6_r6[] = {
  0xd8, 0xbf, 0x76, 0x41 // It le; adc le r6 r6 r6
};
const byte kInstruction_adc_vc_r7_r7_r6[] = {
  0x78, 0xbf, 0x77, 0x41 // It vc; adc vc r7 r7 r6
};
const byte kInstruction_adc_gt_r4_r4_r5[] = {
  0xc8, 0xbf, 0x6c, 0x41 // It gt; adc gt r4 r4 r5
};
const byte kInstruction_adc_le_r1_r1_r4[] = {
  0xd8, 0xbf, 0x61, 0x41 // It le; adc le r1 r1 r4
};
const byte kInstruction_adc_mi_r2_r2_r1[] = {
  0x48, 0xbf, 0x4a, 0x41 // It mi; adc mi r2 r2 r1
};
const byte kInstruction_adc_ls_r3_r3_r1[] = {
  0x98, 0xbf, 0x4b, 0x41 // It ls; adc ls r3 r3 r1
};
const byte kInstruction_adc_vc_r1_r1_r0[] = {
  0x78, 0xbf, 0x41, 0x41 // It vc; adc vc r1 r1 r0
};
const byte kInstruction_adc_ge_r2_r2_r0[] = {
  0xa8, 0xbf, 0x42, 0x41 // It ge; adc ge r2 r2 r0
};
const byte kInstruction_adc_ne_r5_r5_r7[] = {
  0x18, 0xbf, 0x7d, 0x41 // It ne; adc ne r5 r5 r7
};
const byte kInstruction_adc_hi_r3_r3_r0[] = {
  0x88, 0xbf, 0x43, 0x41 // It hi; adc hi r3 r3 r0
};
const byte kInstruction_adc_gt_r4_r4_r1[] = {
  0xc8, 0xbf, 0x4c, 0x41 // It gt; adc gt r4 r4 r1
};
const byte kInstruction_adc_hi_r6_r6_r7[] = {
  0x88, 0xbf, 0x7e, 0x41 // It hi; adc hi r6 r6 r7
};
const byte kInstruction_adc_cs_r6_r6_r2[] = {
  0x28, 0xbf, 0x56, 0x41 // It cs; adc cs r6 r6 r2
};
const byte kInstruction_adc_ne_r6_r6_r2[] = {
  0x18, 0xbf, 0x56, 0x41 // It ne; adc ne r6 r6 r2
};
const byte kInstruction_adc_le_r7_r7_r0[] = {
  0xd8, 0xbf, 0x47, 0x41 // It le; adc le r7 r7 r0
};
const byte kInstruction_adc_vs_r0_r0_r1[] = {
  0x68, 0xbf, 0x48, 0x41 // It vs; adc vs r0 r0 r1
};
const byte kInstruction_adc_vs_r4_r4_r2[] = {
  0x68, 0xbf, 0x54, 0x41 // It vs; adc vs r4 r4 r2
};
const byte kInstruction_adc_eq_r0_r0_r7[] = {
  0x08, 0xbf, 0x78, 0x41 // It eq; adc eq r0 r0 r7
};
const byte kInstruction_adc_lt_r2_r2_r3[] = {
  0xb8, 0xbf, 0x5a, 0x41 // It lt; adc lt r2 r2 r3
};
const byte kInstruction_adc_ne_r5_r5_r4[] = {
  0x18, 0xbf, 0x65, 0x41 // It ne; adc ne r5 r5 r4
};
const byte kInstruction_adc_cc_r4_r4_r5[] = {
  0x38, 0xbf, 0x6c, 0x41 // It cc; adc cc r4 r4 r5
};
const byte kInstruction_adc_lt_r1_r1_r4[] = {
  0xb8, 0xbf, 0x61, 0x41 // It lt; adc lt r1 r1 r4
};
const byte kInstruction_adc_eq_r0_r0_r0[] = {
  0x08, 0xbf, 0x40, 0x41 // It eq; adc eq r0 r0 r0
};
const byte kInstruction_adc_vs_r5_r5_r4[] = {
  0x68, 0xbf, 0x65, 0x41 // It vs; adc vs r5 r5 r4
};
const byte kInstruction_adc_ne_r0_r0_r5[] = {
  0x18, 0xbf, 0x68, 0x41 // It ne; adc ne r0 r0 r5
};
const byte kInstruction_adc_pl_r2_r2_r0[] = {
  0x58, 0xbf, 0x42, 0x41 // It pl; adc pl r2 r2 r0
};
const byte kInstruction_adc_vc_r2_r2_r5[] = {
  0x78, 0xbf, 0x6a, 0x41 // It vc; adc vc r2 r2 r5
};
const byte kInstruction_adc_lt_r3_r3_r1[] = {
  0xb8, 0xbf, 0x4b, 0x41 // It lt; adc lt r3 r3 r1
};
const byte kInstruction_adc_hi_r1_r1_r0[] = {
  0x88, 0xbf, 0x41, 0x41 // It hi; adc hi r1 r1 r0
};
const byte kInstruction_adc_eq_r4_r4_r6[] = {
  0x08, 0xbf, 0x74, 0x41 // It eq; adc eq r4 r4 r6
};
const byte kInstruction_adc_vs_r3_r3_r6[] = {
  0x68, 0xbf, 0x73, 0x41 // It vs; adc vs r3 r3 r6
};
const byte kInstruction_adc_lt_r1_r1_r0[] = {
  0xb8, 0xbf, 0x41, 0x41 // It lt; adc lt r1 r1 r0
};
const byte kInstruction_adc_ls_r2_r2_r2[] = {
  0x98, 0xbf, 0x52, 0x41 // It ls; adc ls r2 r2 r2
};
const byte kInstruction_adc_ge_r3_r3_r3[] = {
  0xa8, 0xbf, 0x5b, 0x41 // It ge; adc ge r3 r3 r3
};
const byte kInstruction_adc_ls_r2_r2_r7[] = {
  0x98, 0xbf, 0x7a, 0x41 // It ls; adc ls r2 r2 r7
};
const byte kInstruction_adc_ge_r4_r4_r5[] = {
  0xa8, 0xbf, 0x6c, 0x41 // It ge; adc ge r4 r4 r5
};
const byte kInstruction_adc_eq_r6_r6_r5[] = {
  0x08, 0xbf, 0x6e, 0x41 // It eq; adc eq r6 r6 r5
};
const byte kInstruction_adc_mi_r2_r2_r3[] = {
  0x48, 0xbf, 0x5a, 0x41 // It mi; adc mi r2 r2 r3
};
const byte kInstruction_adc_mi_r7_r7_r6[] = {
  0x48, 0xbf, 0x77, 0x41 // It mi; adc mi r7 r7 r6
};
const byte kInstruction_adc_ge_r2_r2_r3[] = {
  0xa8, 0xbf, 0x5a, 0x41 // It ge; adc ge r2 r2 r3
};
const byte kInstruction_adc_le_r5_r5_r1[] = {
  0xd8, 0xbf, 0x4d, 0x41 // It le; adc le r5 r5 r1
};
const byte kInstruction_adc_le_r7_r7_r5[] = {
  0xd8, 0xbf, 0x6f, 0x41 // It le; adc le r7 r7 r5
};
const byte kInstruction_adc_ne_r7_r7_r4[] = {
  0x18, 0xbf, 0x67, 0x41 // It ne; adc ne r7 r7 r4
};
const byte kInstruction_adc_lt_r2_r2_r0[] = {
  0xb8, 0xbf, 0x42, 0x41 // It lt; adc lt r2 r2 r0
};
const byte kInstruction_adc_cs_r2_r2_r2[] = {
  0x28, 0xbf, 0x52, 0x41 // It cs; adc cs r2 r2 r2
};
const byte kInstruction_adc_hi_r5_r5_r1[] = {
  0x88, 0xbf, 0x4d, 0x41 // It hi; adc hi r5 r5 r1
};
const byte kInstruction_adc_cc_r5_r5_r2[] = {
  0x38, 0xbf, 0x55, 0x41 // It cc; adc cc r5 r5 r2
};
const byte kInstruction_adc_eq_r6_r6_r0[] = {
  0x08, 0xbf, 0x46, 0x41 // It eq; adc eq r6 r6 r0
};
const byte kInstruction_adc_hi_r5_r5_r5[] = {
  0x88, 0xbf, 0x6d, 0x41 // It hi; adc hi r5 r5 r5
};
const byte kInstruction_adc_hi_r1_r1_r1[] = {
  0x88, 0xbf, 0x49, 0x41 // It hi; adc hi r1 r1 r1
};
const byte kInstruction_adc_eq_r3_r3_r7[] = {
  0x08, 0xbf, 0x7b, 0x41 // It eq; adc eq r3 r3 r7
};
const byte kInstruction_adc_lt_r0_r0_r3[] = {
  0xb8, 0xbf, 0x58, 0x41 // It lt; adc lt r0 r0 r3
};
const byte kInstruction_adc_ne_r7_r7_r0[] = {
  0x18, 0xbf, 0x47, 0x41 // It ne; adc ne r7 r7 r0
};
const byte kInstruction_adc_cs_r1_r1_r0[] = {
  0x28, 0xbf, 0x41, 0x41 // It cs; adc cs r1 r1 r0
};
const byte kInstruction_adc_le_r0_r0_r2[] = {
  0xd8, 0xbf, 0x50, 0x41 // It le; adc le r0 r0 r2
};
const byte kInstruction_adc_gt_r5_r5_r4[] = {
  0xc8, 0xbf, 0x65, 0x41 // It gt; adc gt r5 r5 r4
};
const byte kInstruction_adc_le_r0_r0_r3[] = {
  0xd8, 0xbf, 0x58, 0x41 // It le; adc le r0 r0 r3
};
const byte kInstruction_adc_cs_r7_r7_r0[] = {
  0x28, 0xbf, 0x47, 0x41 // It cs; adc cs r7 r7 r0
};
const byte kInstruction_adc_eq_r7_r7_r2[] = {
  0x08, 0xbf, 0x57, 0x41 // It eq; adc eq r7 r7 r2
};
const byte kInstruction_adc_ne_r4_r4_r3[] = {
  0x18, 0xbf, 0x5c, 0x41 // It ne; adc ne r4 r4 r3
};
const byte kInstruction_adc_mi_r0_r0_r3[] = {
  0x48, 0xbf, 0x58, 0x41 // It mi; adc mi r0 r0 r3
};
const byte kInstruction_adc_cs_r4_r4_r0[] = {
  0x28, 0xbf, 0x44, 0x41 // It cs; adc cs r4 r4 r0
};
const byte kInstruction_adc_ls_r4_r4_r4[] = {
  0x98, 0xbf, 0x64, 0x41 // It ls; adc ls r4 r4 r4
};
const byte kInstruction_adc_le_r3_r3_r6[] = {
  0xd8, 0xbf, 0x73, 0x41 // It le; adc le r3 r3 r6
};
const byte kInstruction_adc_mi_r7_r7_r5[] = {
  0x48, 0xbf, 0x6f, 0x41 // It mi; adc mi r7 r7 r5
};
const byte kInstruction_adc_vs_r7_r7_r4[] = {
  0x68, 0xbf, 0x67, 0x41 // It vs; adc vs r7 r7 r4
};
const byte kInstruction_adc_cc_r0_r0_r4[] = {
  0x38, 0xbf, 0x60, 0x41 // It cc; adc cc r0 r0 r4
};
const byte kInstruction_adc_ls_r0_r0_r4[] = {
  0x98, 0xbf, 0x60, 0x41 // It ls; adc ls r0 r0 r4
};
const byte kInstruction_adc_vs_r3_r3_r5[] = {
  0x68, 0xbf, 0x6b, 0x41 // It vs; adc vs r3 r3 r5
};
const byte kInstruction_adc_lt_r7_r7_r5[] = {
  0xb8, 0xbf, 0x6f, 0x41 // It lt; adc lt r7 r7 r5
};
const byte kInstruction_adc_eq_r1_r1_r7[] = {
  0x08, 0xbf, 0x79, 0x41 // It eq; adc eq r1 r1 r7
};
const byte kInstruction_adc_lt_r7_r7_r4[] = {
  0xb8, 0xbf, 0x67, 0x41 // It lt; adc lt r7 r7 r4
};
const byte kInstruction_adc_cc_r3_r3_r5[] = {
  0x38, 0xbf, 0x6b, 0x41 // It cc; adc cc r3 r3 r5
};
const byte kInstruction_adc_ge_r4_r4_r3[] = {
  0xa8, 0xbf, 0x5c, 0x41 // It ge; adc ge r4 r4 r3
};
const byte kInstruction_adc_cc_r4_r4_r6[] = {
  0x38, 0xbf, 0x74, 0x41 // It cc; adc cc r4 r4 r6
};
const byte kInstruction_adc_hi_r3_r3_r6[] = {
  0x88, 0xbf, 0x73, 0x41 // It hi; adc hi r3 r3 r6
};
const byte kInstruction_adc_gt_r0_r0_r6[] = {
  0xc8, 0xbf, 0x70, 0x41 // It gt; adc gt r0 r0 r6
};
const byte kInstruction_adc_mi_r7_r7_r7[] = {
  0x48, 0xbf, 0x7f, 0x41 // It mi; adc mi r7 r7 r7
};
const byte kInstruction_adc_mi_r6_r6_r2[] = {
  0x48, 0xbf, 0x56, 0x41 // It mi; adc mi r6 r6 r2
};
const byte kInstruction_adc_ne_r1_r1_r5[] = {
  0x18, 0xbf, 0x69, 0x41 // It ne; adc ne r1 r1 r5
};
const byte kInstruction_adc_gt_r1_r1_r2[] = {
  0xc8, 0xbf, 0x51, 0x41 // It gt; adc gt r1 r1 r2
};
const byte kInstruction_adc_lt_r7_r7_r2[] = {
  0xb8, 0xbf, 0x57, 0x41 // It lt; adc lt r7 r7 r2
};
const byte kInstruction_adc_cs_r5_r5_r5[] = {
  0x28, 0xbf, 0x6d, 0x41 // It cs; adc cs r5 r5 r5
};
const byte kInstruction_adc_vc_r1_r1_r2[] = {
  0x78, 0xbf, 0x51, 0x41 // It vc; adc vc r1 r1 r2
};
const byte kInstruction_adc_eq_r5_r5_r6[] = {
  0x08, 0xbf, 0x75, 0x41 // It eq; adc eq r5 r5 r6
};
const byte kInstruction_adc_vc_r5_r5_r2[] = {
  0x78, 0xbf, 0x55, 0x41 // It vc; adc vc r5 r5 r2
};
const byte kInstruction_adc_le_r6_r6_r2[] = {
  0xd8, 0xbf, 0x56, 0x41 // It le; adc le r6 r6 r2
};
const byte kInstruction_adc_le_r6_r6_r4[] = {
  0xd8, 0xbf, 0x66, 0x41 // It le; adc le r6 r6 r4
};
const byte kInstruction_adc_pl_r3_r3_r2[] = {
  0x58, 0xbf, 0x53, 0x41 // It pl; adc pl r3 r3 r2
};
const byte kInstruction_adc_gt_r7_r7_r2[] = {
  0xc8, 0xbf, 0x57, 0x41 // It gt; adc gt r7 r7 r2
};
const byte kInstruction_adc_lt_r6_r6_r7[] = {
  0xb8, 0xbf, 0x7e, 0x41 // It lt; adc lt r6 r6 r7
};
const byte kInstruction_adc_gt_r4_r4_r7[] = {
  0xc8, 0xbf, 0x7c, 0x41 // It gt; adc gt r4 r4 r7
};
const byte kInstruction_adc_vc_r4_r4_r4[] = {
  0x78, 0xbf, 0x64, 0x41 // It vc; adc vc r4 r4 r4
};
const byte kInstruction_adc_vc_r1_r1_r4[] = {
  0x78, 0xbf, 0x61, 0x41 // It vc; adc vc r1 r1 r4
};
const byte kInstruction_adc_hi_r3_r3_r5[] = {
  0x88, 0xbf, 0x6b, 0x41 // It hi; adc hi r3 r3 r5
};
const byte kInstruction_adc_gt_r3_r3_r2[] = {
  0xc8, 0xbf, 0x53, 0x41 // It gt; adc gt r3 r3 r2
};
const byte kInstruction_adc_ge_r5_r5_r7[] = {
  0xa8, 0xbf, 0x7d, 0x41 // It ge; adc ge r5 r5 r7
};
const byte kInstruction_adc_vs_r2_r2_r6[] = {
  0x68, 0xbf, 0x72, 0x41 // It vs; adc vs r2 r2 r6
};
const byte kInstruction_adc_ge_r1_r1_r7[] = {
  0xa8, 0xbf, 0x79, 0x41 // It ge; adc ge r1 r1 r7
};
const byte kInstruction_adc_ne_r6_r6_r1[] = {
  0x18, 0xbf, 0x4e, 0x41 // It ne; adc ne r6 r6 r1
};
const byte kInstruction_adc_eq_r6_r6_r1[] = {
  0x08, 0xbf, 0x4e, 0x41 // It eq; adc eq r6 r6 r1
};
const byte kInstruction_adc_lt_r1_r1_r6[] = {
  0xb8, 0xbf, 0x71, 0x41 // It lt; adc lt r1 r1 r6
};
const byte kInstruction_adc_pl_r4_r4_r0[] = {
  0x58, 0xbf, 0x44, 0x41 // It pl; adc pl r4 r4 r0
};
const byte kInstruction_adc_mi_r3_r3_r0[] = {
  0x48, 0xbf, 0x43, 0x41 // It mi; adc mi r3 r3 r0
};
const byte kInstruction_adc_ne_r6_r6_r6[] = {
  0x18, 0xbf, 0x76, 0x41 // It ne; adc ne r6 r6 r6
};
const byte kInstruction_adc_cs_r1_r1_r3[] = {
  0x28, 0xbf, 0x59, 0x41 // It cs; adc cs r1 r1 r3
};
const byte kInstruction_adc_gt_r7_r7_r6[] = {
  0xc8, 0xbf, 0x77, 0x41 // It gt; adc gt r7 r7 r6
};
const byte kInstruction_adc_cc_r1_r1_r2[] = {
  0x38, 0xbf, 0x51, 0x41 // It cc; adc cc r1 r1 r2
};
const byte kInstruction_adc_vs_r0_r0_r4[] = {
  0x68, 0xbf, 0x60, 0x41 // It vs; adc vs r0 r0 r4
};
const byte kInstruction_adc_ge_r0_r0_r5[] = {
  0xa8, 0xbf, 0x68, 0x41 // It ge; adc ge r0 r0 r5
};
const byte kInstruction_adc_ls_r0_r0_r2[] = {
  0x98, 0xbf, 0x50, 0x41 // It ls; adc ls r0 r0 r2
};
const byte kInstruction_adc_lt_r0_r0_r6[] = {
  0xb8, 0xbf, 0x70, 0x41 // It lt; adc lt r0 r0 r6
};
const byte kInstruction_adc_vc_r3_r3_r4[] = {
  0x78, 0xbf, 0x63, 0x41 // It vc; adc vc r3 r3 r4
};
const byte kInstruction_adc_eq_r3_r3_r1[] = {
  0x08, 0xbf, 0x4b, 0x41 // It eq; adc eq r3 r3 r1
};
const byte kInstruction_adc_vc_r7_r7_r4[] = {
  0x78, 0xbf, 0x67, 0x41 // It vc; adc vc r7 r7 r4
};
const byte kInstruction_adc_vs_r5_r5_r2[] = {
  0x68, 0xbf, 0x55, 0x41 // It vs; adc vs r5 r5 r2
};
const byte kInstruction_adc_cc_r2_r2_r6[] = {
  0x38, 0xbf, 0x72, 0x41 // It cc; adc cc r2 r2 r6
};
const byte kInstruction_adc_cs_r0_r0_r7[] = {
  0x28, 0xbf, 0x78, 0x41 // It cs; adc cs r0 r0 r7
};
const byte kInstruction_adc_vc_r3_r3_r1[] = {
  0x78, 0xbf, 0x4b, 0x41 // It vc; adc vc r3 r3 r1
};
const byte kInstruction_adc_cc_r6_r6_r1[] = {
  0x38, 0xbf, 0x4e, 0x41 // It cc; adc cc r6 r6 r1
};
const byte kInstruction_adc_gt_r4_r4_r0[] = {
  0xc8, 0xbf, 0x44, 0x41 // It gt; adc gt r4 r4 r0
};
const byte kInstruction_adc_mi_r4_r4_r3[] = {
  0x48, 0xbf, 0x5c, 0x41 // It mi; adc mi r4 r4 r3
};
const byte kInstruction_adc_ge_r4_r4_r2[] = {
  0xa8, 0xbf, 0x54, 0x41 // It ge; adc ge r4 r4 r2
};
const byte kInstruction_adc_vc_r2_r2_r1[] = {
  0x78, 0xbf, 0x4a, 0x41 // It vc; adc vc r2 r2 r1
};
const byte kInstruction_adc_mi_r0_r0_r6[] = {
  0x48, 0xbf, 0x70, 0x41 // It mi; adc mi r0 r0 r6
};
const byte kInstruction_adc_gt_r4_r4_r6[] = {
  0xc8, 0xbf, 0x74, 0x41 // It gt; adc gt r4 r4 r6
};
const byte kInstruction_adc_lt_r5_r5_r3[] = {
  0xb8, 0xbf, 0x5d, 0x41 // It lt; adc lt r5 r5 r3
};
const byte kInstruction_adc_hi_r0_r0_r3[] = {
  0x88, 0xbf, 0x58, 0x41 // It hi; adc hi r0 r0 r3
};
const byte kInstruction_adc_ne_r0_r0_r1[] = {
  0x18, 0xbf, 0x48, 0x41 // It ne; adc ne r0 r0 r1
};
const byte kInstruction_adc_ne_r4_r4_r4[] = {
  0x18, 0xbf, 0x64, 0x41 // It ne; adc ne r4 r4 r4
};
const byte kInstruction_adc_vc_r3_r3_r7[] = {
  0x78, 0xbf, 0x7b, 0x41 // It vc; adc vc r3 r3 r7
};
const byte kInstruction_adc_eq_r2_r2_r4[] = {
  0x08, 0xbf, 0x62, 0x41 // It eq; adc eq r2 r2 r4
};
const byte kInstruction_adc_ge_r6_r6_r5[] = {
  0xa8, 0xbf, 0x6e, 0x41 // It ge; adc ge r6 r6 r5
};
const byte kInstruction_adc_vc_r6_r6_r2[] = {
  0x78, 0xbf, 0x56, 0x41 // It vc; adc vc r6 r6 r2
};
const byte kInstruction_adc_hi_r1_r1_r3[] = {
  0x88, 0xbf, 0x59, 0x41 // It hi; adc hi r1 r1 r3
};
const byte kInstruction_adc_pl_r0_r0_r4[] = {
  0x58, 0xbf, 0x60, 0x41 // It pl; adc pl r0 r0 r4
};
const byte kInstruction_adc_vs_r1_r1_r6[] = {
  0x68, 0xbf, 0x71, 0x41 // It vs; adc vs r1 r1 r6
};
const byte kInstruction_adc_cc_r1_r1_r4[] = {
  0x38, 0xbf, 0x61, 0x41 // It cc; adc cc r1 r1 r4
};
const byte kInstruction_adc_lt_r1_r1_r3[] = {
  0xb8, 0xbf, 0x59, 0x41 // It lt; adc lt r1 r1 r3
};
const byte kInstruction_adc_pl_r1_r1_r4[] = {
  0x58, 0xbf, 0x61, 0x41 // It pl; adc pl r1 r1 r4
};
const byte kInstruction_adc_cs_r3_r3_r3[] = {
  0x28, 0xbf, 0x5b, 0x41 // It cs; adc cs r3 r3 r3
};
const byte kInstruction_adc_ge_r7_r7_r0[] = {
  0xa8, 0xbf, 0x47, 0x41 // It ge; adc ge r7 r7 r0
};
const byte kInstruction_adc_ls_r5_r5_r1[] = {
  0x98, 0xbf, 0x4d, 0x41 // It ls; adc ls r5 r5 r1
};
const byte kInstruction_adc_pl_r7_r7_r3[] = {
  0x58, 0xbf, 0x5f, 0x41 // It pl; adc pl r7 r7 r3
};
const byte kInstruction_adc_eq_r2_r2_r1[] = {
  0x08, 0xbf, 0x4a, 0x41 // It eq; adc eq r2 r2 r1
};
const byte kInstruction_adc_mi_r4_r4_r5[] = {
  0x48, 0xbf, 0x6c, 0x41 // It mi; adc mi r4 r4 r5
};
const byte kInstruction_adc_vc_r1_r1_r7[] = {
  0x78, 0xbf, 0x79, 0x41 // It vc; adc vc r1 r1 r7
};
const byte kInstruction_adc_lt_r6_r6_r5[] = {
  0xb8, 0xbf, 0x6e, 0x41 // It lt; adc lt r6 r6 r5
};
const byte kInstruction_adc_ge_r4_r4_r1[] = {
  0xa8, 0xbf, 0x4c, 0x41 // It ge; adc ge r4 r4 r1
};
const byte kInstruction_adc_gt_r1_r1_r7[] = {
  0xc8, 0xbf, 0x79, 0x41 // It gt; adc gt r1 r1 r7
};
const byte kInstruction_adc_lt_r0_r0_r5[] = {
  0xb8, 0xbf, 0x68, 0x41 // It lt; adc lt r0 r0 r5
};
const byte kInstruction_adc_le_r4_r4_r0[] = {
  0xd8, 0xbf, 0x44, 0x41 // It le; adc le r4 r4 r0
};
const byte kInstruction_adc_le_r1_r1_r3[] = {
  0xd8, 0xbf, 0x59, 0x41 // It le; adc le r1 r1 r3
};
const byte kInstruction_adc_cs_r6_r6_r0[] = {
  0x28, 0xbf, 0x46, 0x41 // It cs; adc cs r6 r6 r0
};
const TestResult kReferenceadc[] = {
  {
    ARRAY_SIZE(kInstruction_adc_gt_r3_r3_r0),
    kInstruction_adc_gt_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r6_r6_r1),
    kInstruction_adc_ge_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r7_r7_r1),
    kInstruction_adc_gt_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r2_r2_r0),
    kInstruction_adc_gt_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r5_r5_r2),
    kInstruction_adc_eq_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r0_r0_r0),
    kInstruction_adc_gt_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r0_r0_r4),
    kInstruction_adc_lt_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r6_r6_r3),
    kInstruction_adc_hi_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r7_r7_r6),
    kInstruction_adc_ge_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r5_r5_r5),
    kInstruction_adc_eq_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r1_r1_r0),
    kInstruction_adc_cc_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r1_r1_r1),
    kInstruction_adc_cc_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r4_r4_r3),
    kInstruction_adc_cc_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r5_r5_r3),
    kInstruction_adc_mi_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r3_r3_r0),
    kInstruction_adc_cs_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r0_r0_r6),
    kInstruction_adc_pl_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r4_r4_r4),
    kInstruction_adc_cc_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r3_r3_r6),
    kInstruction_adc_cc_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r7_r7_r3),
    kInstruction_adc_hi_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r7_r7_r5),
    kInstruction_adc_vs_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r2_r2_r7),
    kInstruction_adc_le_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r5_r5_r3),
    kInstruction_adc_le_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r1_r1_r5),
    kInstruction_adc_vs_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r7_r7_r3),
    kInstruction_adc_vs_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r0_r0_r3),
    kInstruction_adc_cc_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r2_r2_r5),
    kInstruction_adc_cc_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r7_r7_r7),
    kInstruction_adc_gt_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r7_r7_r2),
    kInstruction_adc_ls_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r0_r0_r2),
    kInstruction_adc_lt_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r3_r3_r4),
    kInstruction_adc_ne_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r3_r3_r7),
    kInstruction_adc_ge_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r5_r5_r7),
    kInstruction_adc_hi_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r0_r0_r3),
    kInstruction_adc_vc_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r7_r7_r3),
    kInstruction_adc_cc_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r5_r5_r4),
    kInstruction_adc_ls_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r0_r0_r1),
    kInstruction_adc_vc_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r0_r0_r6),
    kInstruction_adc_hi_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r7_r7_r3),
    kInstruction_adc_mi_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r7_r7_r4),
    kInstruction_adc_cc_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r0_r0_r3),
    kInstruction_adc_pl_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r5_r5_r0),
    kInstruction_adc_ls_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r2_r2_r5),
    kInstruction_adc_ls_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r0_r0_r3),
    kInstruction_adc_ls_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r5_r5_r1),
    kInstruction_adc_pl_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r1_r1_r1),
    kInstruction_adc_mi_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r5_r5_r3),
    kInstruction_adc_ls_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r2_r2_r7),
    kInstruction_adc_gt_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r2_r2_r5),
    kInstruction_adc_ge_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r7_r7_r3),
    kInstruction_adc_gt_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r6_r6_r3),
    kInstruction_adc_vs_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r1_r1_r7),
    kInstruction_adc_cc_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r0_r0_r1),
    kInstruction_adc_ls_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r3_r3_r1),
    kInstruction_adc_gt_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r7_r7_r3),
    kInstruction_adc_cs_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r5_r5_r3),
    kInstruction_adc_gt_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r2_r2_r5),
    kInstruction_adc_le_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r1_r1_r0),
    kInstruction_adc_ne_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r7_r7_r7),
    kInstruction_adc_ne_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r2_r2_r1),
    kInstruction_adc_lt_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r3_r3_r1),
    kInstruction_adc_vs_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r7_r7_r5),
    kInstruction_adc_gt_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r6_r6_r1),
    kInstruction_adc_ls_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r7_r7_r4),
    kInstruction_adc_pl_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r6_r6_r7),
    kInstruction_adc_ls_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r5_r5_r3),
    kInstruction_adc_eq_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r2_r2_r7),
    kInstruction_adc_lt_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r7_r7_r6),
    kInstruction_adc_pl_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r1_r1_r6),
    kInstruction_adc_cs_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r0_r0_r3),
    kInstruction_adc_cs_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r3_r3_r2),
    kInstruction_adc_mi_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r4_r4_r5),
    kInstruction_adc_eq_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r3_r3_r4),
    kInstruction_adc_cs_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r7_r7_r6),
    kInstruction_adc_ls_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r0_r0_r7),
    kInstruction_adc_vs_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r2_r2_r1),
    kInstruction_adc_pl_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r0_r0_r5),
    kInstruction_adc_vs_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r4_r4_r2),
    kInstruction_adc_vc_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r4_r4_r7),
    kInstruction_adc_vc_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r4_r4_r7),
    kInstruction_adc_cs_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r5_r5_r2),
    kInstruction_adc_ne_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r1_r1_r5),
    kInstruction_adc_eq_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r0_r0_r7),
    kInstruction_adc_cc_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r4_r4_r0),
    kInstruction_adc_lt_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r2_r2_r6),
    kInstruction_adc_eq_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r2_r2_r1),
    kInstruction_adc_le_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r4_r4_r4),
    kInstruction_adc_mi_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r5_r5_r6),
    kInstruction_adc_ne_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r0_r0_r7),
    kInstruction_adc_gt_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r2_r2_r7),
    kInstruction_adc_hi_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r5_r5_r6),
    kInstruction_adc_vs_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r4_r4_r1),
    kInstruction_adc_eq_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r7_r7_r0),
    kInstruction_adc_eq_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r2_r2_r6),
    kInstruction_adc_ne_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r4_r4_r1),
    kInstruction_adc_vc_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r2_r2_r0),
    kInstruction_adc_le_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r5_r5_r5),
    kInstruction_adc_lt_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r3_r3_r7),
    kInstruction_adc_pl_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r1_r1_r5),
    kInstruction_adc_pl_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r3_r3_r1),
    kInstruction_adc_le_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r3_r3_r2),
    kInstruction_adc_vs_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r1_r1_r3),
    kInstruction_adc_pl_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r4_r4_r3),
    kInstruction_adc_le_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r6_r6_r1),
    kInstruction_adc_vs_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r1_r1_r1),
    kInstruction_adc_cs_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r2_r2_r6),
    kInstruction_adc_ge_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r0_r0_r0),
    kInstruction_adc_ls_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r5_r5_r1),
    kInstruction_adc_mi_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r4_r4_r1),
    kInstruction_adc_hi_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r3_r3_r2),
    kInstruction_adc_eq_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r5_r5_r1),
    kInstruction_adc_cc_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r6_r6_r2),
    kInstruction_adc_eq_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r4_r4_r2),
    kInstruction_adc_hi_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r5_r5_r0),
    kInstruction_adc_gt_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r3_r3_r2),
    kInstruction_adc_hi_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r0_r0_r0),
    kInstruction_adc_pl_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r3_r3_r7),
    kInstruction_adc_lt_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r7_r7_r1),
    kInstruction_adc_ls_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r3_r3_r3),
    kInstruction_adc_gt_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r6_r6_r6),
    kInstruction_adc_cs_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r3_r3_r2),
    kInstruction_adc_cc_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r4_r4_r0),
    kInstruction_adc_ne_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r4_r4_r5),
    kInstruction_adc_vs_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r6_r6_r4),
    kInstruction_adc_ge_r6_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r5_r5_r3),
    kInstruction_adc_ne_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r3_r3_r0),
    kInstruction_adc_vs_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r5_r5_r2),
    kInstruction_adc_lt_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r6_r6_r4),
    kInstruction_adc_lt_r6_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r2_r2_r5),
    kInstruction_adc_hi_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r7_r7_r5),
    kInstruction_adc_eq_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r4_r4_r5),
    kInstruction_adc_lt_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r7_r7_r3),
    kInstruction_adc_ls_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r3_r3_r5),
    kInstruction_adc_lt_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r5_r5_r0),
    kInstruction_adc_cs_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r2_r2_r3),
    kInstruction_adc_vc_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r1_r1_r4),
    kInstruction_adc_cs_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r5_r5_r4),
    kInstruction_adc_pl_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r7_r7_r4),
    kInstruction_adc_hi_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r3_r3_r6),
    kInstruction_adc_ge_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r3_r3_r2),
    kInstruction_adc_ls_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r3_r3_r3),
    kInstruction_adc_mi_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r6_r6_r5),
    kInstruction_adc_le_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r5_r5_r7),
    kInstruction_adc_pl_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r2_r2_r3),
    kInstruction_adc_ne_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r2_r2_r6),
    kInstruction_adc_ls_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r1_r1_r6),
    kInstruction_adc_le_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r6_r6_r7),
    kInstruction_adc_cc_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r4_r4_r3),
    kInstruction_adc_pl_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r0_r0_r3),
    kInstruction_adc_ne_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r6_r6_r6),
    kInstruction_adc_cc_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r7_r7_r5),
    kInstruction_adc_ls_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r1_r1_r5),
    kInstruction_adc_ls_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r0_r0_r0),
    kInstruction_adc_le_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r4_r4_r6),
    kInstruction_adc_ge_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r1_r1_r6),
    kInstruction_adc_cc_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r4_r4_r3),
    kInstruction_adc_eq_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r7_r7_r4),
    kInstruction_adc_ls_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r3_r3_r0),
    kInstruction_adc_eq_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r4_r4_r3),
    kInstruction_adc_lt_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r3_r3_r4),
    kInstruction_adc_le_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r4_r4_r4),
    kInstruction_adc_le_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r0_r0_r6),
    kInstruction_adc_ge_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r7_r7_r2),
    kInstruction_adc_hi_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r5_r5_r6),
    kInstruction_adc_pl_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r4_r4_r7),
    kInstruction_adc_pl_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r3_r3_r6),
    kInstruction_adc_gt_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r6_r6_r6),
    kInstruction_adc_eq_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r5_r5_r0),
    kInstruction_adc_cc_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r5_r5_r0),
    kInstruction_adc_hi_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r5_r5_r5),
    kInstruction_adc_gt_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r2_r2_r4),
    kInstruction_adc_vs_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r1_r1_r3),
    kInstruction_adc_vs_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r7_r7_r6),
    kInstruction_adc_lt_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r2_r2_r2),
    kInstruction_adc_ge_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r1_r1_r5),
    kInstruction_adc_mi_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r5_r5_r0),
    kInstruction_adc_ge_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r6_r6_r3),
    kInstruction_adc_le_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r7_r7_r5),
    kInstruction_adc_hi_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r3_r3_r4),
    kInstruction_adc_gt_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r3_r3_r3),
    kInstruction_adc_cc_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r2_r2_r2),
    kInstruction_adc_hi_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r7_r7_r3),
    kInstruction_adc_lt_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r6_r6_r6),
    kInstruction_adc_ls_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r7_r7_r7),
    kInstruction_adc_le_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r4_r4_r6),
    kInstruction_adc_cs_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r5_r5_r4),
    kInstruction_adc_ge_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r1_r1_r2),
    kInstruction_adc_ge_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r0_r0_r7),
    kInstruction_adc_pl_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r1_r1_r2),
    kInstruction_adc_vs_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r6_r6_r5),
    kInstruction_adc_mi_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r0_r0_r1),
    kInstruction_adc_mi_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r0_r0_r5),
    kInstruction_adc_vc_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r5_r5_r5),
    kInstruction_adc_cc_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r5_r5_r5),
    kInstruction_adc_pl_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r2_r2_r0),
    kInstruction_adc_ne_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r3_r3_r4),
    kInstruction_adc_cc_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r3_r3_r3),
    kInstruction_adc_ls_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r2_r2_r1),
    kInstruction_adc_cc_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r3_r3_r4),
    kInstruction_adc_ge_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r0_r0_r6),
    kInstruction_adc_ne_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r2_r2_r0),
    kInstruction_adc_vs_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r1_r1_r2),
    kInstruction_adc_ne_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r6_r6_r5),
    kInstruction_adc_ne_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r7_r7_r0),
    kInstruction_adc_pl_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r6_r6_r2),
    kInstruction_adc_pl_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r1_r1_r2),
    kInstruction_adc_pl_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r6_r6_r3),
    kInstruction_adc_gt_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r0_r0_r4),
    kInstruction_adc_vc_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r4_r4_r5),
    kInstruction_adc_vc_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r2_r2_r3),
    kInstruction_adc_vs_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r2_r2_r3),
    kInstruction_adc_pl_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r5_r5_r2),
    kInstruction_adc_hi_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r6_r6_r1),
    kInstruction_adc_le_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r3_r3_r0),
    kInstruction_adc_ne_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r7_r7_r1),
    kInstruction_adc_mi_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r7_r7_r7),
    kInstruction_adc_lt_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r5_r5_r7),
    kInstruction_adc_gt_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r1_r1_r1),
    kInstruction_adc_vc_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r1_r1_r2),
    kInstruction_adc_lt_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r6_r6_r6),
    kInstruction_adc_vs_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r5_r5_r5),
    kInstruction_adc_le_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r6_r6_r7),
    kInstruction_adc_gt_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r3_r3_r1),
    kInstruction_adc_cc_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r1_r1_r0),
    kInstruction_adc_ls_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r6_r6_r2),
    kInstruction_adc_vs_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r7_r7_r0),
    kInstruction_adc_mi_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r0_r0_r1),
    kInstruction_adc_gt_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r0_r0_r0),
    kInstruction_adc_ne_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r6_r6_r1),
    kInstruction_adc_lt_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r5_r5_r5),
    kInstruction_adc_ge_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r2_r2_r4),
    kInstruction_adc_lt_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r4_r4_r3),
    kInstruction_adc_vs_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r5_r5_r2),
    kInstruction_adc_cs_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r1_r1_r1),
    kInstruction_adc_gt_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r5_r5_r6),
    kInstruction_adc_cs_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r6_r6_r2),
    kInstruction_adc_gt_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r2_r2_r0),
    kInstruction_adc_cc_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r2_r2_r5),
    kInstruction_adc_lt_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r1_r1_r6),
    kInstruction_adc_mi_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r4_r4_r0),
    kInstruction_adc_hi_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r5_r5_r2),
    kInstruction_adc_le_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r5_r5_r7),
    kInstruction_adc_eq_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r5_r5_r0),
    kInstruction_adc_eq_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r0_r0_r1),
    kInstruction_adc_le_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r2_r2_r4),
    kInstruction_adc_cs_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r5_r5_r4),
    kInstruction_adc_cc_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r5_r5_r0),
    kInstruction_adc_mi_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r1_r1_r0),
    kInstruction_adc_le_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r2_r2_r2),
    kInstruction_adc_mi_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r4_r4_r2),
    kInstruction_adc_ls_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r3_r3_r1),
    kInstruction_adc_ne_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r3_r3_r1),
    kInstruction_adc_hi_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r4_r4_r1),
    kInstruction_adc_pl_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r7_r7_r7),
    kInstruction_adc_pl_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r3_r3_r0),
    kInstruction_adc_ge_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r6_r6_r0),
    kInstruction_adc_vs_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r1_r1_r5),
    kInstruction_adc_gt_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r1_r1_r7),
    kInstruction_adc_ls_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r5_r5_r3),
    kInstruction_adc_hi_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r5_r5_r2),
    kInstruction_adc_ls_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r6_r6_r2),
    kInstruction_adc_ls_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r7_r7_r7),
    kInstruction_adc_cs_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r3_r3_r2),
    kInstruction_adc_le_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r6_r6_r0),
    kInstruction_adc_le_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r4_r4_r4),
    kInstruction_adc_pl_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r1_r1_r3),
    kInstruction_adc_ne_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r5_r5_r1),
    kInstruction_adc_ge_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r4_r4_r7),
    kInstruction_adc_eq_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r7_r7_r1),
    kInstruction_adc_pl_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r6_r6_r7),
    kInstruction_adc_vs_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r2_r2_r6),
    kInstruction_adc_vc_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r7_r7_r6),
    kInstruction_adc_hi_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r1_r1_r1),
    kInstruction_adc_le_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r4_r4_r1),
    kInstruction_adc_cs_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r1_r1_r2),
    kInstruction_adc_mi_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r3_r3_r5),
    kInstruction_adc_pl_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r7_r7_r1),
    kInstruction_adc_eq_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r0_r0_r5),
    kInstruction_adc_cs_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r3_r3_r5),
    kInstruction_adc_ge_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r6_r6_r3),
    kInstruction_adc_pl_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r7_r7_r5),
    kInstruction_adc_cc_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r4_r4_r6),
    kInstruction_adc_lt_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r7_r7_r2),
    kInstruction_adc_ne_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r3_r3_r0),
    kInstruction_adc_vc_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r7_r7_r6),
    kInstruction_adc_cc_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r0_r0_r0),
    kInstruction_adc_vc_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r7_r7_r3),
    kInstruction_adc_vc_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r7_r7_r0),
    kInstruction_adc_vs_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r2_r2_r0),
    kInstruction_adc_eq_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r2_r2_r1),
    kInstruction_adc_ne_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r7_r7_r2),
    kInstruction_adc_pl_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r3_r3_r6),
    kInstruction_adc_vc_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r5_r5_r1),
    kInstruction_adc_vs_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r2_r2_r2),
    kInstruction_adc_vs_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r6_r6_r6),
    kInstruction_adc_pl_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r6_r6_r3),
    kInstruction_adc_ge_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r2_r2_r6),
    kInstruction_adc_lt_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r5_r5_r6),
    kInstruction_adc_ls_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r7_r7_r6),
    kInstruction_adc_le_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r0_r0_r2),
    kInstruction_adc_ge_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r0_r0_r4),
    kInstruction_adc_le_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r6_r6_r3),
    kInstruction_adc_ls_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r6_r6_r0),
    kInstruction_adc_ls_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r4_r4_r7),
    kInstruction_adc_vs_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r4_r4_r4),
    kInstruction_adc_cs_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r7_r7_r5),
    kInstruction_adc_cs_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r6_r6_r3),
    kInstruction_adc_cs_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r7_r7_r4),
    kInstruction_adc_eq_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r6_r6_r0),
    kInstruction_adc_pl_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r5_r5_r4),
    kInstruction_adc_hi_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r6_r6_r6),
    kInstruction_adc_lt_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r7_r7_r2),
    kInstruction_adc_le_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r4_r4_r1),
    kInstruction_adc_le_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r4_r4_r6),
    kInstruction_adc_ne_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r0_r0_r1),
    kInstruction_adc_hi_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r6_r6_r5),
    kInstruction_adc_gt_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r5_r5_r6),
    kInstruction_adc_cc_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r3_r3_r4),
    kInstruction_adc_ls_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r6_r6_r6),
    kInstruction_adc_vc_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r4_r4_r2),
    kInstruction_adc_pl_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r6_r6_r3),
    kInstruction_adc_lt_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r1_r1_r0),
    kInstruction_adc_mi_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r0_r0_r2),
    kInstruction_adc_cc_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r5_r5_r5),
    kInstruction_adc_ne_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r7_r7_r4),
    kInstruction_adc_cs_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r7_r7_r0),
    kInstruction_adc_vc_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r2_r2_r2),
    kInstruction_adc_cc_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r0_r0_r4),
    kInstruction_adc_ge_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r4_r4_r4),
    kInstruction_adc_gt_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r3_r3_r6),
    kInstruction_adc_cs_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r4_r4_r2),
    kInstruction_adc_cc_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r1_r1_r6),
    kInstruction_adc_eq_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r4_r4_r6),
    kInstruction_adc_mi_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r4_r4_r4),
    kInstruction_adc_eq_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r2_r2_r6),
    kInstruction_adc_gt_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r5_r5_r7),
    kInstruction_adc_lt_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r4_r4_r2),
    kInstruction_adc_lt_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r6_r6_r1),
    kInstruction_adc_cs_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r2_r2_r7),
    kInstruction_adc_vs_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r6_r6_r6),
    kInstruction_adc_hi_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r0_r0_r3),
    kInstruction_adc_vs_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r0_r0_r2),
    kInstruction_adc_mi_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r7_r7_r1),
    kInstruction_adc_cs_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r1_r1_r6),
    kInstruction_adc_gt_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r3_r3_r7),
    kInstruction_adc_vs_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r1_r1_r5),
    kInstruction_adc_hi_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r4_r4_r1),
    kInstruction_adc_lt_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r6_r6_r6),
    kInstruction_adc_le_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r7_r7_r6),
    kInstruction_adc_vc_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r4_r4_r5),
    kInstruction_adc_gt_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r1_r1_r4),
    kInstruction_adc_le_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r2_r2_r1),
    kInstruction_adc_mi_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r3_r3_r1),
    kInstruction_adc_ls_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r1_r1_r0),
    kInstruction_adc_vc_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r2_r2_r0),
    kInstruction_adc_ge_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r5_r5_r7),
    kInstruction_adc_ne_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r3_r3_r0),
    kInstruction_adc_hi_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r4_r4_r1),
    kInstruction_adc_gt_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r6_r6_r7),
    kInstruction_adc_hi_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r6_r6_r2),
    kInstruction_adc_cs_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r6_r6_r2),
    kInstruction_adc_ne_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r7_r7_r0),
    kInstruction_adc_le_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r0_r0_r1),
    kInstruction_adc_vs_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r4_r4_r2),
    kInstruction_adc_vs_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r0_r0_r7),
    kInstruction_adc_eq_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r2_r2_r3),
    kInstruction_adc_lt_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r5_r5_r4),
    kInstruction_adc_ne_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r4_r4_r5),
    kInstruction_adc_cc_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r1_r1_r4),
    kInstruction_adc_lt_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r0_r0_r0),
    kInstruction_adc_eq_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r5_r5_r4),
    kInstruction_adc_vs_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r0_r0_r5),
    kInstruction_adc_ne_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r2_r2_r0),
    kInstruction_adc_pl_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r2_r2_r5),
    kInstruction_adc_vc_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r3_r3_r1),
    kInstruction_adc_lt_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r1_r1_r0),
    kInstruction_adc_hi_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r4_r4_r6),
    kInstruction_adc_eq_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r3_r3_r6),
    kInstruction_adc_vs_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r1_r1_r0),
    kInstruction_adc_lt_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r2_r2_r2),
    kInstruction_adc_ls_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r3_r3_r3),
    kInstruction_adc_ge_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r2_r2_r7),
    kInstruction_adc_ls_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r4_r4_r5),
    kInstruction_adc_ge_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r6_r6_r5),
    kInstruction_adc_eq_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r2_r2_r3),
    kInstruction_adc_mi_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r7_r7_r6),
    kInstruction_adc_mi_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r2_r2_r3),
    kInstruction_adc_ge_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r5_r5_r1),
    kInstruction_adc_le_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r7_r7_r5),
    kInstruction_adc_le_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r7_r7_r4),
    kInstruction_adc_ne_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r2_r2_r0),
    kInstruction_adc_lt_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r2_r2_r2),
    kInstruction_adc_cs_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r5_r5_r1),
    kInstruction_adc_hi_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r5_r5_r2),
    kInstruction_adc_cc_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r6_r6_r0),
    kInstruction_adc_eq_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r5_r5_r5),
    kInstruction_adc_hi_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r1_r1_r1),
    kInstruction_adc_hi_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r3_r3_r7),
    kInstruction_adc_eq_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r0_r0_r3),
    kInstruction_adc_lt_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r7_r7_r0),
    kInstruction_adc_ne_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r1_r1_r0),
    kInstruction_adc_cs_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r0_r0_r2),
    kInstruction_adc_le_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r5_r5_r4),
    kInstruction_adc_gt_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r0_r0_r3),
    kInstruction_adc_le_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r7_r7_r0),
    kInstruction_adc_cs_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r7_r7_r2),
    kInstruction_adc_eq_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r4_r4_r3),
    kInstruction_adc_ne_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r0_r0_r3),
    kInstruction_adc_mi_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r4_r4_r0),
    kInstruction_adc_cs_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r4_r4_r4),
    kInstruction_adc_ls_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r3_r3_r6),
    kInstruction_adc_le_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r7_r7_r5),
    kInstruction_adc_mi_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r7_r7_r4),
    kInstruction_adc_vs_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r0_r0_r4),
    kInstruction_adc_cc_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r0_r0_r4),
    kInstruction_adc_ls_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r3_r3_r5),
    kInstruction_adc_vs_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r7_r7_r5),
    kInstruction_adc_lt_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r1_r1_r7),
    kInstruction_adc_eq_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r7_r7_r4),
    kInstruction_adc_lt_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r3_r3_r5),
    kInstruction_adc_cc_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r4_r4_r3),
    kInstruction_adc_ge_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r4_r4_r6),
    kInstruction_adc_cc_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r3_r3_r6),
    kInstruction_adc_hi_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r0_r0_r6),
    kInstruction_adc_gt_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r7_r7_r7),
    kInstruction_adc_mi_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r6_r6_r2),
    kInstruction_adc_mi_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r1_r1_r5),
    kInstruction_adc_ne_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r1_r1_r2),
    kInstruction_adc_gt_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r7_r7_r2),
    kInstruction_adc_lt_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r5_r5_r5),
    kInstruction_adc_cs_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r1_r1_r2),
    kInstruction_adc_vc_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r5_r5_r6),
    kInstruction_adc_eq_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r5_r5_r2),
    kInstruction_adc_vc_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r6_r6_r2),
    kInstruction_adc_le_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r6_r6_r4),
    kInstruction_adc_le_r6_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r3_r3_r2),
    kInstruction_adc_pl_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r7_r7_r2),
    kInstruction_adc_gt_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r6_r6_r7),
    kInstruction_adc_lt_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r4_r4_r7),
    kInstruction_adc_gt_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r4_r4_r4),
    kInstruction_adc_vc_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r1_r1_r4),
    kInstruction_adc_vc_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r3_r3_r5),
    kInstruction_adc_hi_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r3_r3_r2),
    kInstruction_adc_gt_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r5_r5_r7),
    kInstruction_adc_ge_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r2_r2_r6),
    kInstruction_adc_vs_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r1_r1_r7),
    kInstruction_adc_ge_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r6_r6_r1),
    kInstruction_adc_ne_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r6_r6_r1),
    kInstruction_adc_eq_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r1_r1_r6),
    kInstruction_adc_lt_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r4_r4_r0),
    kInstruction_adc_pl_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r3_r3_r0),
    kInstruction_adc_mi_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r6_r6_r6),
    kInstruction_adc_ne_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r1_r1_r3),
    kInstruction_adc_cs_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r7_r7_r6),
    kInstruction_adc_gt_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r1_r1_r2),
    kInstruction_adc_cc_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r0_r0_r4),
    kInstruction_adc_vs_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r0_r0_r5),
    kInstruction_adc_ge_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r0_r0_r2),
    kInstruction_adc_ls_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r0_r0_r6),
    kInstruction_adc_lt_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r3_r3_r4),
    kInstruction_adc_vc_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r3_r3_r1),
    kInstruction_adc_eq_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r7_r7_r4),
    kInstruction_adc_vc_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r5_r5_r2),
    kInstruction_adc_vs_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r2_r2_r6),
    kInstruction_adc_cc_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r0_r0_r7),
    kInstruction_adc_cs_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r3_r3_r1),
    kInstruction_adc_vc_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r6_r6_r1),
    kInstruction_adc_cc_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r4_r4_r0),
    kInstruction_adc_gt_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r4_r4_r3),
    kInstruction_adc_mi_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r4_r4_r2),
    kInstruction_adc_ge_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r2_r2_r1),
    kInstruction_adc_vc_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r0_r0_r6),
    kInstruction_adc_mi_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r4_r4_r6),
    kInstruction_adc_gt_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r5_r5_r3),
    kInstruction_adc_lt_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r0_r0_r3),
    kInstruction_adc_hi_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r0_r0_r1),
    kInstruction_adc_ne_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ne_r4_r4_r4),
    kInstruction_adc_ne_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r3_r3_r7),
    kInstruction_adc_vc_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r2_r2_r4),
    kInstruction_adc_eq_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r6_r6_r5),
    kInstruction_adc_ge_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r6_r6_r2),
    kInstruction_adc_vc_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_adc_hi_r1_r1_r3),
    kInstruction_adc_hi_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r0_r0_r4),
    kInstruction_adc_pl_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vs_r1_r1_r6),
    kInstruction_adc_vs_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cc_r1_r1_r4),
    kInstruction_adc_cc_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r1_r1_r3),
    kInstruction_adc_lt_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r1_r1_r4),
    kInstruction_adc_pl_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r3_r3_r3),
    kInstruction_adc_cs_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r7_r7_r0),
    kInstruction_adc_ge_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ls_r5_r5_r1),
    kInstruction_adc_ls_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_pl_r7_r7_r3),
    kInstruction_adc_pl_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_eq_r2_r2_r1),
    kInstruction_adc_eq_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_mi_r4_r4_r5),
    kInstruction_adc_mi_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_vc_r1_r1_r7),
    kInstruction_adc_vc_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r6_r6_r5),
    kInstruction_adc_lt_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_ge_r4_r4_r1),
    kInstruction_adc_ge_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_adc_gt_r1_r1_r7),
    kInstruction_adc_gt_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_adc_lt_r0_r0_r5),
    kInstruction_adc_lt_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r4_r4_r0),
    kInstruction_adc_le_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_adc_le_r1_r1_r3),
    kInstruction_adc_le_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_adc_cs_r6_r6_r0),
    kInstruction_adc_cs_r6_r6_r0,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_ALL_LOW_RD_IS_RN_IN_IT_BLOCK_ADC_T32_H_
